%% This file computes counterfactual earnings for job loser and expresses them relative to realized earnings
%  It does so 1) for a "treatment group" that is defined exactly as in the
%  displacement regressions (high tenure at the same employer) and then it
%  does so for 2) a "treatment group" which is simply all job losers and then 3) a group of short term employed (up to 3 years since unemployment exit).
%  It then compares the two and plots a figure and constructs the PV
%  earnings losses

% run this file separately for i=1,2,3 (the three different cases)

clear all
close all


clc

rng('default')
%Parameters from Estimation
load 'best_params722' lam0 lam1 alph up down by1 by2 bd1 bd2 thet ymin z

load omega %weighting matrix
load mom_targ %empirical target moments
load numerical_params %grid size, number of firms, workers,...

ny=groups; % firms differ in terms of productivity and security, code is built such that as many different y types as d types
nd=groups;
nf=ny*nd;

x=linspace(xmin,xmax,nx);
tend=tstart+samplerep;

[dn,ytil]=copula_new(by1,by2,bd1,bd2,thet,groups); %the copula file builds the joint distribution of job across the two dimensions
yn=ymin+ytil;

tic
%solve value functions
[Sxv2,w,WU,rs]= values_full_with_u(dn,yn,bet,lam0,lam1,alph,nx,nf,x,up,down,z,by1,by2,bd1,bd2,thet,ymin);

clear losses

tstart=37;

i=1;  % THIS SELECTS THE CASE, then st to 2 and 3

clear sim_dat stat firm bench hc hcneg wage surplus wu 
T2=296; %296; 26 years
N=75000; %% 75k for whats in paper
simdat=[];
NSim =10; % 10 for whats in paper
stat=[];
firm=[];
bench=[];
hc=[];
hcneg=[];
wage=[];
surplus=[];
wu=[];

for j=1:8 % 16 for whats in the paper
j
tic
parfor kk=1:NSim
     [stat, firm, hc, wage, firmp, workerp, espell, jspell, uspell, bench, hcneg]=dataset_only_extended(Sxv2,w,WU,dn,yn,bet,lam0,lam1,alph,ny,nx,nd,nf,x,up,down,z,T2,N,rs);
     sim_dat(:,:,kk)=[stat, firm, bench, hc, hcneg, wage]
     
end
toc

tic
stat1=[reshape(sim_dat(:,1:N,:),T2,N*NSim) ];
firm1=[reshape(sim_dat(:,N+1:2*N,:),T2,N*NSim) ];
bench1=[reshape(sim_dat(:,2*N+1:3*N,:),T2,N*NSim) ] ;
hc1=[reshape(sim_dat(:,3*N+1:4*N,:),T2,N*NSim) ];
hcneg1=[reshape(sim_dat(:,4*N+1:5*N,:),T2,N*NSim) ];
wage1=[reshape(sim_dat(:,5*N+1:6*N,:),T2,N*NSim) ];
%surplus1=[reshape(sim_dat(:,6*N+1:7*N,:),T2,N*NSim) ];
%wu1=[reshape(sim_dat(:,7*N+1:8*N,:),T2,N*NSim) ];

clearvars simdat

% Select high tenured job losers
  t=tstart;
  t2=1;
if i==1
  samp2=(sum(stat1(t2:t-2,:))==tstart-2 & stat1(t-1,:)==0 &sum(firm1(t2:t-2,:))./(tstart-2)==firm1(t-2,:));% job losers w/ selection criterion
elseif i==2
  samp2=(stat1(t-2,:)==1 & stat1(t-1,:)==0);% job losers w/ selection criterion
elseif i==3
   % samp2=((sum(stat1(t2:t-2,:))<tstart-2 | sum(firm1(t2:t-2,:))./(tstart-2)<firm1(t-2,:)) & stat1(t-1,:)==0);% job losers w/ selection criterion
    samp2=(sum(stat1(t2:t-2,:))<tstart-2 & stat1(t-1,:)==0);% job losers w/ selection criterion
end

  samp2_ind=logical(samp2);
   
  stat1=stat1(:,samp2_ind);
  firm1=firm1(:,samp2_ind);
  bench1=bench1(:,samp2_ind);
  hc1=hc1(:,samp2_ind);
  hcneg1=hcneg1(:,samp2_ind);
  wage1=wage1(:,samp2_ind);
 % surplus1=surplus1(:,samp2_ind);
 % wu1=wu1(:,samp2_ind);

stat=[stat stat1];
firm=[firm firm1];
bench=[bench bench1] ;
hc=[hc hc1];
hcneg=[hcneg hcneg1];
wage=[wage wage1];
%surplus=[surplus surplus1];
%wu=[wu wu1];

clearvars stat1 firm1 hc1 wage1 firm1 hcneg1
toc
end

N2=size(stat,2);
   
%% This blocks creates random realizations to simulate counterfactuals
  fu=(rand(T2,N2)<lam0);
  fj=(rand(T2,N2)<lam1);
  s=rand(T2,N2);
  draw=ceil(rand(T2,N2)*nf);
  Sst=Sxv2(:);
  WUst=WU(:);
  wst=w(:);
  
%% this block computes counterfactual wages for the treatment group letting everything stochastically evolve assuming job loss did not happen
statcf2=stat;
firmcf2=firm;
benchcf2=bench;
hcnegcf2=hcneg;
hccf2=hc;
up_s=(rand(T2,N2)<up);
down_s=(rand(T2,N2)<down);

   
for t=tstart-1:T2
    if t==tstart-1
        statcf2(t,:)=ones(1,N2);
    else
        statcf2(t,:)=statcf2(t-1,:).*(1-(s(t,:)<dn(firmcf2(t-1,:))'))+(1-statcf2(t-1,:)).*fu(t,:).*[Sst((hccf2(t-1,:)-1)*nf+draw(t-1,:))>0]';
    end
    hccf2(t,:)=statcf2(t,:).*(up_s(t,:).*min(hccf2(t-1,:)+1,nx)+(1-up_s(t,:)).*hccf2(t-1,:))+...
        (1-statcf2(t,:)).*(down_s(t,:).*max(hccf2(t-1,:)-1,1)+(1-down_s(t,:)).*hccf2(t-1,:));
    
    firmcf2(t,:)=(statcf2(t,:)-statcf2(t-1,:)==1).*draw(t,:)+(statcf2(t,:)==1).*((statcf2(t-1,:)==1)).*...
        (fj(t,:).*(Sxv2(draw(t,:)+(hccf2(t,:)-1)*nf)>Sxv2(firmcf2(t-1,:)+(hccf2(t,:)-1)*nf)).*draw(t,:)+...
        (1-fj(t,:).*(Sxv2(draw(t,:)+(hccf2(t,:)-1)*nf)>Sxv2(firmcf2(t-1,:)+(hccf2(t,:)-1)*nf))).*firmcf2(t-1,:))...
        +(1-statcf2(t,:)).*firmcf2(t-1,:);
    
   reneg=rs((draw(t,:)-1)*nx*nx*nf*(nf+1)+(hccf2(t,:)-1)*nx*nf*(nf+1)+(hcnegcf2(t-1,:)-1)*nf*(nf+1)+(benchcf2(t-1,:))*nf+(firmcf2(t-1,:)))';
   
   benchcf2(t,:)=(statcf2(t,:)-statcf2(t-1,:)==1).*zeros(1,N2)+(1-(statcf2(t,:)==1)).*zeros(1,N2)+...
        (statcf2(t,:)==1).*(statcf2(t-1,:)==1).*...
        (fj(t,:).*(Sxv2(draw(t,:)+(hccf2(t,:)-1)*nf)>Sxv2(firmcf2(t-1,:)+(hccf2(t,:)-1)*nf)).*firmcf2(t-1,:)+...
        fj(t,:).*reneg.*draw(t,:)+...
        ((1-fj(t,:))+fj(t,:).*(1-(Sxv2(draw(t,:)+(hccf2(t,:)-1)*nf)>Sxv2(firmcf2(t-1,:)+(hccf2(t,:)-1)*nf))-reneg)).*benchcf2(t-1,:));    

   hcnegcf2(t,:)=statcf2(t,:).*(((benchcf2(t,:)~=benchcf2(t-1,:)) | ((firmcf2(t,:)~=firmcf2(t-1,:)))).*hccf2(t,:)+...
        +(1-((benchcf2(t,:)~=benchcf2(t-1,:)) | (firmcf2(t,:)~=firmcf2(t-1,:)))).*hcnegcf2(t-1,:))+...
        (1-statcf2(t,:)).*hccf2(t,:);
    
    t;
end

%     windcount=(hccf2-1)*nf*(nf+1)*nx+(hcnegcf2-1)*(nf*(nf+1))+benchcf2*nf+firmcf2;
%     earncount=wst(windcount).*statcf2;
    windcount=(hcnegcf2-1)*nf*(nf+1)+(benchcf2)*nf+firmcf2;
    earncount=wst(windcount).*statcf2;
    
    earn=wage.*stat;
    meanearn=mean(earn,2);
    meanearncount=mean(earncount,2);
    
    count3=sum(statcf2,2);
    meanwagecount=sum(earncount,2)./count3;
    meanwage=sum(earn,2)./sum(stat,2)
        
    for tt=1:20
    mearn(i,tt)=mean(meanearn(tstart-1+(tt-1)*12:tstart-1+tt*12));
    mearncount(i,tt)=mean(meanearncount(tstart-1+(tt-1)*12:tstart-1+tt*12));
    mwage(i,tt)=mean(meanwage(tstart-1+(tt-1)*12:tstart-1+tt*12));
    mwagecount(i,tt)=mean(meanwagecount(tstart-1+(tt-1)*12:tstart-1+tt*12));
    end
    

losses=mearn./mearncount;
lossesw=mwage./mwagecount;
pvloss=1-(sum(bet.^(linspace(0,19,20)).*mearn,2))./(sum((bet.^(linspace(0,19,20)).*mearncount),2))    

filename = strcat('eloss',num2str(i)');
save(filename, 'losses', 'pvloss', 'mearn', 'mearncount')

