function [LE, LE_V, E, E_V, LW, LW_V, W, W_V, JL, JL_V] = import_reg_results(file_n, dataLines)
%IMPORTFILE Import data from a text file
%  [LE, LE_V, E, E_V, LW, LW_V, W, W_V, JL, JL_V] = IMPORTFILE(FILENAME)
%  reads data from text file FILENAME for the default selection.
%  Returns the data as column vectors.
%
%  [LE, LE_V, E, E_V, LW, LW_V, W, W_V, JL, JL_V] = IMPORTFILE(FILE,
%  DATALINES) reads data for the specified row interval(s) of text file
%  FILENAME. Specify DATALINES as a positive scalar integer or a N-by-2
%  array of positive scalar integers for dis-contiguous row intervals.
%
%  Example:
%  [LE, LE_V, E, E_V, LW, LW_V, W, W_V, JL, JL_V] = importfile("C:\Users\gjarosch\Dropbox\JMP\German Data\Test_Data_Revision\log\losses1_final.txt", [2, Inf]);
%
%  See also READTABLE.
%
% Auto-generated by MATLAB on 29-Jul-2022 11:32:57

filename = strcat('C:\Users\gjarosch\Dropbox\JMP\German Data\Test_Data_Revision\log\losses',num2str(file_n),'_final.txt');

%% Input handling

% If dataLines is not specified, define defaults
if nargin < 2
    dataLines = [2, Inf];
end

%% Setup the Import Options and import the data
opts = delimitedTextImportOptions("NumVariables", 11);

% Specify range and delimiter
opts.DataLines = dataLines;
opts.Delimiter = "\t";

% Specify column names and types
opts.VariableNames = ["Var1", "LE", "LE_V", "E", "E_V", "LW", "LW_V", "W", "W_V", "JL", "JL_V"];
opts.SelectedVariableNames = ["LE", "LE_V", "E", "E_V", "LW", "LW_V", "W", "W_V", "JL", "JL_V"];
opts.VariableTypes = ["string", "double", "double", "double", "double", "double", "double", "double", "double", "double", "double"];

% Specify file level properties
opts.ExtraColumnsRule = "ignore";
opts.EmptyLineRule = "read";

% Specify variable properties
opts = setvaropts(opts, "Var1", "WhitespaceRule", "preserve");
opts = setvaropts(opts, "Var1", "EmptyFieldRule", "auto");

% Import the data
tbl = readtable(filename, opts);

%% Convert to output type
LE = tbl.LE;
LE_V = tbl.LE_V;
E = tbl.E;
E_V = tbl.E_V;
LW = tbl.LW;
LW_V = tbl.LW_V;
W = tbl.W;
W_V = tbl.W_V;
JL = tbl.JL;
JL_V = tbl.JL_V;
end