%%% This file produces most of the results in "Searching for Job Security
%%% and the Consequences of Job Loss"

% In particular, it computes most of the figures and statistics that I
% report following the model estimation

%% This block loads the parameters estimates and files storing numerical parameters and then computes the associated solution of the model and distance to targets once
clear all
close all
clc

rng('default')
%Parameters from Estimation
load 'best_params722' lam0 lam1 alph up down by1 by2 bd1 bd2 thet ymin z

load omega %weighting matrix
load mom_targ %empirical target moments
load numerical_params %grid size, number of firms, workers,...

ny=groups; % firms differ in terms of productivity and security, code is built such that as many different y types as d types
nd=groups;
nf=ny*nd;

x=linspace(xmin,xmax,nx);
tend=tstart+samplerep;

[dn,ytil]=copula_new(by1,by2,bd1,bd2,thet,groups); %the copula file builds the joint distribution of job across the two dimensions
yn=ymin+ytil;

tic
%solve value functions
[Sxv2,w,WU,rs]= values_full_with_u(dn,yn,bet,lam0,lam1,alph,nx,nf,x,up,down,z,by1,by2,bd1,bd2,thet,ymin);
%compute simulated worker datasets 
[stat, firm, hc, wage, firmp, workerp, espell, jspell, uspell, bench, hcneg]=dataset_only_extended(Sxv2,w,WU,dn,yn,bet,lam0,lam1,alph,ny,nx,nd,nf,x,up,down,z,T,N,rs);

%compute moments off simulated data
[mom_est] =moments(stat, firm, hc, wage, espell, jspell, uspell,N,T,lam1, z,yn,x)
[mom_est;mom_targ]

%distance model-data
LL = sum((log(mom_targ./mom_est)).^2./omega,2) 
toc
%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%% MODEL DIAGNOSTICS %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%% Indifference Curves 
run('indiff')

%% Joint Distribution of Job Attributes
corr(yn,dn,'Type','Spearman')

X=linspace(0,1,1000)
%y1=betapdf(X,1.5, 49)
%y2=betapdf(X,10.95, 10.05)

[hhhhh ynpdf]=histfit2((yn(firm(:))-ymin)./max(yn(firm(:))-ymin),100,'beta','pdf');
[hhhhh dnpdf]=histfit2(dn(firm(:)),100,'beta','pdf');
[hhhhh ynpdfu]=histfit2((yn(firm(espell==1))-ymin)./max(yn(firm(espell==1))-ymin),100,'beta','pdf');
[hhhhh dnpdfu]=histfit2(dn(firm(espell==1)),100,'beta','pdf');

figure(1)
subplot(2,2,1)
plot(X,pdf(dnpdfu,X),'--g',X,pdf(dnpdf,X),'m','LineWidth',2)
xh1=xlabel('$\theta_{\delta}$','Interpreter','latex')
axis([0,0.1,0,80])
subplot(2,2,2)
plot(X,cdf(dnpdfu,X),'--g',X,cdf(dnpdf,X),'m','LineWidth',2)
xh2=xlabel('$\theta_{\delta}$','Interpreter','latex')
axis([0,0.1,0,1])
subplot(2,2,3)
plot(X,pdf(ynpdfu,X),'--g',X,pdf(ynpdf,X),'m','LineWidth',2)
xh3=xlabel('$\theta_{y}$','Interpreter','latex')
subplot(2,2,4)
plot(X,cdf(ynpdfu,X),'--g',X,cdf(ynpdf,X),'m','LineWidth',2)
xh4=xlabel('$\theta_{y}$','Interpreter','latex')
leg=legend('Newly Employed','All Employed','Location','NorthEast')
set([leg],'fontweight','bold','fontsize',10);
set([xh1,xh2,xh3,xh4],'fontweight','bold','fontsize',15);
print -depsc2 distribution_d.eps

% std dev of log firm component
std(log(yn(firm(stat==1)))) 
std(log(yn(firm(stat==1 & hc==round(mean(hc(stat==1))))))) % conditional on mean hc
    
%% Sorting - Figure looks at all 20 worker types. For each type, compute the fraction at the least (median, most) productive firm. 
% THIS FIGURE CONSIDERS THREE DIFFERENT FIRMS, (MIN MAX MED) AND ALLOCATES
% THE TOTAL EMPLOYMENT OF HIGHEST AND LOWEST WORKER TYPE ACROSS THE TWO

    %[ypos,medy]=min(abs(yn-median(yn))); %identify median p firm
    % 

    [stat, firm, hc, wage, firmp, workerp, espell, jspell, uspell, bench, hcneg]=dataset_only_extended(Sxv2,w,WU,dn,yn,bet,lam0,lam1,alph,ny,nx,nd,nf,x,up,down,z,T,N*5,rs); %needs a slightly larger dataset to smooth out simulation noise

    
    for i=1:nx 
    hoyy(i,1)=sum(sum([workerp==x(i) & (firmp==min(yn) | firmp==max(yn))]));
    hoyy(i,2)=sum(sum([workerp==x(i) & firmp==min(yn)]));
    hoyy(i,3)=sum(sum([workerp==x(i) & firmp==max(yn)]));
    end
    
    xxx=linspace(1,20,20)
    rell=hoyy./repmat(hoyy(:,1),1,3)
    
    figure(3)
    scatter(xxx, rell(:,2),'fill')
    hold
    scatter(xxx, rell(:,3),'fill')
    yh=ylabel('Frac. of Employment at Firm')
    xh=xlabel('Worker Skill Type')
    tit=title('Sorting')
    leg=legend('Least Productive Firm','Most Productive Firm')
    set([yh,leg, xh,tit],'fontweight','bold','fontsize',12)
    print -depsc2 sorting.eps

    corr(firmp(stat==1),workerp(stat==1),'Type','Pearson')
    corr(firmp(stat==1),workerp(stat==1),'Type','Spearman')
    %corr(firmp(sel),workerp(sel))

%% plot distribution of skill 

tme=repmat(linspace(1,size(hc,1),size(hc,1))',1,size(hc,2));
figure(4)
cf0=cdfplot(hc(stat==0 & tme>size(hc,1)-96 & uspell>18))
hold
cf1=cdfplot(hc(stat==0 & tme>size(hc,1)-96))
cf2=cdfplot(hc(stat==0 & tme>size(hc,1)-96 & uspell<=6))
cf3=cdfplot(hc(tme>size(hc,1)-96))
cf0.LineWidth=3
cf1.LineWidth=3
cf2.LineWidth=3
cf3.LineWidth=3
xh=xlabel('Skill Type')
%tit=title('Stationary distribution of human capital')
leg=legend('LTU','Unemployed','STU','Population','Location', 'NorthWest')
set([xh,leg],'fontweight','bold','fontsize',15)
print -depsc2 dist_skill_cdf.eps
hold off

%% Duration Dependence 
% (computes duration dependence in separations the same way the moment function does)
% then compares that with its empirical counterpart (durd_emp)
    
    load durd_emp % this contains the empirical counterpart (copied from file 32_moments which contains the vector DD_full computed in German Data)

    layoff=(stat==0 & lagmatrix(stat,1)==1);
    stat_3=lagmatrix(stat,1);
    tmax=20;
    duration=linspace(0,tmax-1,tmax);
    for tt=1:tmax
    high_tt=logical(lagmatrix(espell,1)>(tt-1)*12 & lagmatrix(espell,1)<=(tt)*12);
    sept(tt)=sum(layoff(high_tt))/sum(stat_3(high_tt)==1);
    end
    sept=sept-sept(1);
    
    figure(5)
    plot(sept(1:10), 'LineStyle', '--', 'Color', 'r','LineWidth',3)
    hold
    plot(durd_emp-durd_emp(1), 'LineStyle', '-.', 'Color', 'b','LineWidth',3)
    %tit=title('Duration Dependence in Job Loss')
    yh=ylabel('Avg Monthly Sep Rate rel. to 1st Year')
    xh=xlabel('Year of Continuos Employment')
    leg=legend('Model','Data')
    set([xh,yh,leg],'fontweight','bold','fontsize',15);
    %axis([-.5 .5 0 1])
    print -depsc2 DD_jobloss.eps
    hold off
    
    % next we construct the figure that projects unemployment risk on job
    % and employment tenure. the data come from duration_test.log file that
    % runs the regressions empirically

    load dd_test
    
    figure(6)
    subplot(3,1,1)
    plot(dd_test(:,1)-dd_test(1,1), 'LineStyle', '-.', 'Color', 'b','LineWidth',3)
    axis([1 10 -.03 0])
    leg=legend('Employment Tenure')
    set([leg],'fontweight','bold','fontsize',15);
    subplot(3,1,2)
    plot(dd_test(:,2)-dd_test(1,2), 'LineStyle', ':', 'Color', 'c','LineWidth',3)
    leg=legend('Job Tenure')
    yh=ylabel('Avg Monthly Sep Rate rel. to 1st Year')
    set([yh,leg ],'fontweight','bold','fontsize',15);
    axis([1 10 -.03 0])
    subplot(3,1,3)
    plot(dd_test(:,3)-dd_test(1,3), 'LineStyle', '-.', 'Color', 'b','LineWidth',3)
    hold
    plot(dd_test(:,4)-dd_test(1,4), 'LineStyle', ':', 'Color', 'c','LineWidth',3)
    xh=xlabel('Years')
    set([xh],'fontweight','bold','fontsize',15);
    axis([1 10 -.03 0])
    print -depsc2 dd_test.eps
    hold off
    

    %% distribution of residualized log earnings
    close
    load lwp_data % this contains the empirical counterpart (copied from file 32_moments which contains the vector with the percentiles of the residualized wage distribution computed in German Data)
    whelp=wage;
    whelp(whelp==0)=nan;
    meanwage=repmat(nanmean(log(whelp),1),T,1);
    lw=log(wage(:))-meanwage(:);
    lwp=lw(isfinite(lw));
        
    figure(6)
    h=cdfplot(lwp)
    hold
    h2=plot(lwp_data, linspace(1,99,99)/100)
    tit=title('Residual Wage Dispersion')
    xh=xlabel('$\omega_{it}-\bar{\omega}_i$','Interpreter','latex')
    leg=legend('Model','Data','Location','SouthEast')
    set([xh,tit,leg],'fontweight','bold','fontsize',15);
    set( h, 'LineStyle', '--', 'Color', 'r','LineWidth',2);
    set( h2, 'LineStyle', '--', 'Color', 'b','LineWidth',2);
    axis([-.5 .5 0 1])
    print -depsc2 wage_dispersion.eps
    hold off
    
%% Earnings Losses for Various Workers in the Model (section 4.4)
run('earnings_losses')

% Load Simulations (final version saved manually as _final) and Construct Results for Paper

load eloss1_final
elosses(1,:)=losses(end,:);
load eloss2_final
elosses(2,:)=losses(end,:);
load eloss3_final
elosses(3,:)=losses(end,:);



figure(2)
plot(elosses','LineWidth',2.5)
xh=xlabel('Years After Job Loss')
yh=ylabel('Earnings Losses - Model')
leg=legend('Long Term Employed', 'All Job Losers', 'Short Term Employed', 'Location', 'SouthEast')
set([xh,yh,leg],'fontweight','bold','fontsize',15);
axis([1,20,0.2,1])
print('C:\Users\gjarosch\Dropbox\JMP\Drafts\Draft\pics\losses_diff.eps','-depsc')


%% decomposition of wage losses (first part of section 4.3)
rng('default')          

run('decomposition_new')

%% simulated dataset for STATA, THEN NEED TO IMPORT (WITH IMPORT_FAKE.DO, AFTER COPYING INTO SIMUL SUBFOLDER) AND RUN DISPLACEMENT REGRESIONS
rng('default')

% 1) BASELINE
create_fake(1,Sxv2,w,WU,dn,yn,bet,lam0,lam1,alph,ny,nx,nd,nf,x,up,down,z,rs)

% 2) WITHOUT DELTA HETEROGENEITY FOR second exercise in section 4.3 

dn=mom_targ(3)*ones(size(dn))
[Sxv2,w,WU,rs]= values_full_with_u(dn,yn,bet,lam0,lam1,alph,nx,nf,x,up,down,z,by1,by2,bd1,bd2,thet,ymin);
create_fake(2,Sxv2,w,WU,dn,yn,bet,lam0,lam1,alph,ny,nx,nd,nf,x,up,down,z,rs)

% 3) WITHOUT SKILL HETEROGENEITY FOR second exercise in section 4.3 

%figure out mean ability under baseline
load best_params722
[dn,ytil]=copula_new(by1,by2,bd1,bd2,thet,groups);
yn=ymin+ytil;
[Sxv2,w,WU,rs]= values_full_with_u(dn,yn,bet,lam0,lam1,alph,nx,nf,x,up,down,z,by1,by2,bd1,bd2,thet,ymin);
[stat, firm, hc, wage, firmp, workerp, espell, jspell, uspell, bench, hcneg]=dataset_only_extended(Sxv2,w,WU,dn,yn,bet,lam0,lam1,alph,ny,nx,nd,nf,x,up,down,z,T,N,rs);
meanp=mean(workerp(:));

xmin=meanp;
xmax=meanp;
x=linspace(xmin,xmax,nx);
tend=tstart+samplerep;
[dn,ytil]=copula_new(by1,by2,bd1,bd2,thet,groups);
yn=ymin+ytil;
[Sxv2,w,WU,rs]= values_full_with_u(dn,yn,bet,lam0,lam1,alph,nx,nf,x,up,down,z,by1,by2,bd1,bd2,thet,ymin);
create_fake(3,Sxv2,w,WU,dn,yn,bet,lam0,lam1,alph,ny,nx,nd,nf,x,up,down,z,rs)
%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%% MODEL VS DATA %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% now we contrast model and data. to that end we apply the same stata code
% that we use to analyze the German data to a model generated dataset.

%% Distribution of \delta across firms 
% load the histogram files that stata produces on actual and simulated data

load churn_dat_m
load churn_dat_d

X=linspace(-.05,.05,1000)
dn_d=randsample(churn_dat1_d(:,4),10000,'true',churn_dat1_d(:,3));
dn_m=randsample(churn_dat1_m(:,4),10000,'true',churn_dat1_m(:,3));
[hhhhh dnpdf_d]=histfit2(dn_d,100,'normal','pdf');
[hhhhh dnpdf_m]=histfit2(dn_m,100,'normal','pdf');
h2=figure(2)
plot(X,pdf(dnpdf_d,X),X,pdf(dnpdf_m,X),'--r','LineWidth',3)
xh=xlabel('Residual Unemployment Risk at the Employer Level','Interpreter','latex')
leg=legend('Data','Model','Location','NorthEast')
set([leg,xh],'fontweight','bold','fontsize',15);
axis([-.05,.05,0,90])
print -depsc2 d_distribution1.eps


X=linspace(0,.15,1000)
dn_d=randsample(churn_dat2_d(:,4),10000,'true',churn_dat2_d(:,3));
dn_m=randsample(churn_dat2_m(:,4),10000,'true',churn_dat2_m(:,3));
[hhhhh dnpdf_d]=histfit2(dn_d,100,'normal','pdf');
[hhhhh dnpdf_m]=histfit2(dn_m,100,'normal','pdf');
h2=figure(2)
plot(X,pdf(dnpdf_d,X),X,pdf(dnpdf_m,X),'--r','LineWidth',3)
xh=xlabel('Unemployment Risk Employer Fixed Effect','Interpreter','latex')
leg=legend('Data','Model','Location','NorthEast')
set([leg,xh],'fontweight','bold','fontsize',15);
axis([0,.15,0,25])
print -depsc2 d_distribution2.eps

% rest is not used (old)

% load perm_d
% 
% plot(perm_dates, var_perm_d,'--k','LineWidth',2.5)
% hold
% plot(perm_dates, var_perm_age_d,'LineWidth',2.5)
% plot(perm_dates, var_perm_m,'k','LineWidth',2.5)
% xh=xlabel('Year')
% leg=legend('Data','Data_w_age','Model','Location','NorthWest')
% set([leg,xh],'fontweight','bold','fontsize',15);
%  axis([1981,2004,0,2.5])
%  print -depsc2 perm.eps
 


%% Figures (and additional statistics/results for reduced section)
run('regression_results')


%% GMM Standard errors of the parameter estimates UPDATE FILES (INCLUDING THOSE FOR CLUSTER) TO BEST_PARAMS722
run('standard_errors')


