%% this plots all the figures for the reduced form displacement stuff (it imports results from stata)
 % below it also computes present value earnings losses in model and data
 
close all
clear 

load numerical_params % just for discount factor

%% Data - Baseline Results
% i=1:6 corresponds to 6 different empirical specifications, see stata
% file with displacement regressions

%PV earnings losses for baseline

load('res_empirical1')
pve=mean(LE(6:end).*bet.^linspace(0,20,21))
pve2=mean((E(6:end)-1).*bet.^linspace(0,20,21))
pvw=mean(LW(6:end).*bet.^linspace(0,20,21))

for ii=1:6 
load(strcat('res_empirical',num2str(ii)))

figure(1)
plot(linspace(-6,19,26),zeros(1,26),'--k')
hold
plot(linspace(-5,20,26),LW,'linewidth',3)
xh=xlabel('Years Around Separation')
yh=ylabel('Log Wage - Data')
set([xh,yh],'fontweight','bold','fontsize',15);
axis([-5 20 -.2 .05])
print(strcat('C:\Users\gjarosch\Dropbox\JMP\Drafts\Draft\pics\loss_w_data',num2str(ii),'.eps'),'-depsc')
hold off


figure(2)
plot(linspace(-6,19,26),zeros(1,26),'--k')
hold
plot(linspace(-5,20,26),LE,'linewidth',3)
xh=xlabel('Years Around Separation')
yh=ylabel('Log Earnings - Data')
set([xh,yh],'fontweight','bold','fontsize',15);axis([-5 20 -.7 .07])
print(strcat('C:\Users\gjarosch\Dropbox\JMP\Drafts\Draft\pics\loss_e_data',num2str(ii),'.eps'),'-depsc')
hold off

figure(3)
plot(linspace(-5,20,26),LE,'g','linewidth',3)
hold
plot(linspace(-5,20,26),-E,'m','linewidth',3)
plot(linspace(-6,19,26),zeros(1,26),'--k')
xh=xlabel('Years Around Separation')
yh=ylabel('Earnings - Data')
leg=legend('Log Earnings','Levels')
set([xh,yh,leg],'fontweight','bold','fontsize',15);axis([-5 20 -.7 .07])
print(strcat('C:\Users\gjarosch\Dropbox\JMP\Drafts\Draft\pics\loss_evsle_data',num2str(ii),'.eps'),'-depsc')
hold off

figure(4)
plot(linspace(-5,20,26),LW,'g','linewidth',3)
hold
plot(linspace(-5,20,26),-W,'m','linewidth',3)
plot(linspace(-6,19,26),zeros(1,26),'--k')
xh=xlabel('Years Around Separation')
yh=ylabel('Wages - Data')
leg=legend('Log Wages','Levels')
set([xh,yh,leg],'fontweight','bold','fontsize',15);
axis([-5 20 -.2 .05])
print(strcat('C:\Users\gjarosch\Dropbox\JMP\Drafts\Draft\pics\loss_wvslw_data',num2str(ii),'.eps'),'-depsc')
hold off

figure(5)
line=plot(linspace(-6,19,26),zeros(1,26),'--k')
set(get(get(line,'Annotation'),'LegendInformation'),...
    'IconDisplayStyle','off');
hold
plot(linspace(-5,20,26),-W,'-k',linspace(-5,20,26),-E,'--k','linewidth',3)
leg=legend('Wages','Earnings','Location','SouthEast') 
xh=xlabel('Years Around Separation')
yh=ylabel('% Change Wage and Earnings - Data')
set([xh,yh],'fontweight','bold','fontsize',15);
axis([-5 20 -.6 .07])
legend('boxoff')
print(strcat('C:\Users\gjarosch\Dropbox\JMP\Drafts\Draft\pics\loss_eandw_alt_data',num2str(ii),'.eps'),'-depsc')
axis([0 20 -.65 .07])
print(strcat('C:\Users\gjarosch\Dropbox\JMP\Drafts\Draft\pics\loss_eandw_alt_datab',num2str(ii),'.eps'),'-depsc')
hold off


figure(6)
line=plot(linspace(-6,19,26),zeros(1,26),'--k')
set(get(get(line,'Annotation'),'LegendInformation'),...
    'IconDisplayStyle','off');
hold
plot(linspace(-5,20,26),LW,'-b',linspace(-5,20,26),LE,'--b','linewidth',3)
leg=legend('Wages','Earnings','Location','SouthEast') 
xh=xlabel('Years Around Separation')
yh=ylabel('Log Wage and Earnings - Data')
set([xh,yh],'fontweight','bold','fontsize',15);
axis([-5 20 -.6 .07])
legend('boxoff')
print(strcat('C:\Users\gjarosch\Dropbox\JMP\Drafts\Draft\pics\loss_eandw_data',num2str(ii),'.eps'),'-depsc')
axis([0 20 -.65 .07])
print(strcat('C:\Users\gjarosch\Dropbox\JMP\Drafts\Draft\pics\loss_eandw_datab',num2str(ii),'.eps'),'-depsc')
hold off

figure(7)
line=plot(linspace(-6,19,26),zeros(1,26),'--k')
set(get(get(line,'Annotation'),'LegendInformation'),...
    'IconDisplayStyle','off');
hold
plot(linspace(-5,20,26),(1+LE)./(1+LW)-1,'b','linewidth',3)
xh=xlabel('Years Around Separation')
yh=ylabel('Employment - Data')
set([xh,yh],'fontweight','bold','fontsize',15);axis([-5 20 -.65 .05])
print(strcat('C:\Users\gjarosch\Dropbox\JMP\Drafts\Draft\pics\loss_emp_data',num2str(ii),'.eps'),'-depsc')
hold off

figure(8)
plot(linspace(-6,19,26),zeros(1,26),'--k')
hold
plot(linspace(-5,20,26),LW,'b','linewidth',3)
plot(linspace(-5,20,26),LW+1.96*LW_V.^.5,'--k')
plot(linspace(-5,20,26),LW-1.96*LW_V.^.5,'--k')
xh=xlabel('Years Around Separation')
yh=ylabel('Wage - Data')
set([xh,yh],'fontweight','bold','fontsize',15);
axis([-7 20 -.2 .05])
print(strcat('C:\Users\gjarosch\Dropbox\JMP\Drafts\Draft\pics\loss_w95_data',num2str(ii),'.eps'),'-depsc')
axis([0 20 -.2 .05])
print(strcat('C:\Users\gjarosch\Dropbox\JMP\Drafts\Draft\pics\loss_w95_datab',num2str(ii),'.eps'),'-depsc')
hold off

figure(9)
plot(linspace(-6,19,26),zeros(1,26),'--k')
hold
plot(linspace(-5,20,26),LE,'b','linewidth',3)
plot(linspace(-5,20,26),LE+1.96*LE_V.^.5,'--k')
plot(linspace(-5,20,26),LE-1.96*LE_V.^.5,'--k')
xh=xlabel('Years Around Separation')
yh=ylabel('Earnings - Data')
set([xh,yh],'fontweight','bold','fontsize',15);
axis([-6 20 -.65 .07])
print(strcat('C:\Users\gjarosch\Dropbox\JMP\Drafts\Draft\pics\loss_e95_data',num2str(ii),'.eps'),'-depsc')
axis([0 20 -.65 .07])
print(strcat('C:\Users\gjarosch\Dropbox\JMP\Drafts\Draft\pics\loss_e95_datab',num2str(ii),'.eps'),'-depsc')
hold off

figure(10)
line=plot(linspace(-6,19,26),zeros(1,26),'--k')
set(get(get(line,'Annotation'),'LegendInformation'),...
    'IconDisplayStyle','off');
hold
plot(linspace(-5,20,26),LW,'-k',linspace(-5,20,26),LE,'--k','linewidth',3)
plot(linspace(-5,20,26),LE+1.96*LE_V.^.5,'--k')
plot(linspace(-5,20,26),LE-1.96*LE_V.^.5,'--k')
plot(linspace(-5,20,26),LW+1.96*LW_V.^.5,'--k')
plot(linspace(-5,20,26),LW-1.96*LW_V.^.5,'--k')
leg=legend('Wages','Earnings','Location','SouthEast') 
xh=xlabel('Years Around Separation')
yh=ylabel('Log Wage and Earnings - Data')
set([xh,yh],'fontweight','bold','fontsize',15);
legend('boxoff')
axis([-5 20 -.6 .07])
print(strcat('C:\Users\gjarosch\Dropbox\JMP\Drafts\Draft\pics\loss_eandw95_data',num2str(ii),'.eps'),'-depsc')
axis([0 20 -.6 .07])
print(strcat('C:\Users\gjarosch\Dropbox\JMP\Drafts\Draft\pics\loss_eandw95_datab',num2str(ii),'.eps'),'-depsc')
hold off

if ii==1

figure(55)
line=plot(linspace(-6,19,26),zeros(1,26),'--k')
set(get(get(line,'Annotation'),'LegendInformation'),...
    'IconDisplayStyle','off');
hold
plot(linspace(-5,20,26),-W,'-k',linspace(-5,20,26),-E,'--k','linewidth',3)
plot(linspace(-5,20,26),-E+1.96*E_V.^.5,'--k')
plot(linspace(-5,20,26),-E-1.96*E_V.^.5,'--k')
plot(linspace(-5,20,26),-W+1.96*W_V.^.5,'--k')
plot(linspace(-5,20,26),-W-1.96*W_V.^.5,'--k')
leg=legend('Wages','Earnings','Location','SouthEast') 
xh=xlabel('Years Around Separation')
yh=ylabel('% Change Wage and Earnings - Data')
set([xh,yh],'fontweight','bold','fontsize',15);
axis([-5 20 -.6 .07])
legend('boxoff')
print(strcat('C:\Users\gjarosch\Dropbox\JMP\Drafts\Draft\pics\loss_eandw95_alt_data',num2str(ii),'.eps'),'-depsc')
hold off

end

LEmp=(1+LE)./(1+LW)-1
LEmp_V=((1+LE)./(1+LW)).^2.*((LW_V)./((1+LW).^2)+(LE_V)./((1+LE).^2))

figure(11)
line=plot(linspace(-6,19,26),zeros(1,26),'--k')
set(get(get(line,'Annotation'),'LegendInformation'),...
    'IconDisplayStyle','off');
hold
plot(linspace(-5,20,26),LEmp,'b','linewidth',3)
plot(linspace(-5,20,26),LEmp+1.96*LEmp_V.^.5,'--k')
plot(linspace(-5,20,26),LEmp-1.96*LEmp_V.^.5,'--k')
xh=xlabel('Years Around Separation')
yh=ylabel('Employment - Data')
set([xh,yh],'fontweight','bold','fontsize',15);
axis([-5 20 -.5 .05])
print(strcat('C:\Users\gjarosch\Dropbox\JMP\Drafts\Draft\pics\loss_emp95_data',num2str(ii),'.eps'),'-depsc')
axis([0 20 -.5 .05])
print(strcat('C:\Users\gjarosch\Dropbox\JMP\Drafts\Draft\pics\loss_emp95_datab',num2str(ii),'.eps'),'-depsc')
hold off

figure(12)
plot(linspace(1,20,20),JL(7:end),'linewidth',3)
xh=xlabel('Years Around Separation')
yh=ylabel('Risk of Separation - Data')
set([xh,yh],'fontweight','bold','fontsize',15);
axis([1 20 0 .15])
print(strcat('C:\Users\gjarosch\Dropbox\JMP\Drafts\Draft\pics\loss_jl_data',num2str(ii),'.eps'),'-depsc')
hold off 

figure(13)
plot(linspace(1,20,20),JL(7:end),'linewidth',3)
hold
plot(linspace(1,20,20),JL(7:end)+1.96*JL_V(7:end).^.5,'--k')
plot(linspace(1,20,20),JL(7:end)-1.96*JL_V(7:end).^.5,'--k')
xh=xlabel('Years Around Separation')
yh=ylabel('Risk of Separation - Data')
set([xh,yh],'fontweight','bold','fontsize',15);
axis([1 20 0 .15])
print(strcat('C:\Users\gjarosch\Dropbox\JMP\Drafts\Draft\pics\loss_jl95_data',num2str(ii),'.eps'),'-depsc')
hold off 
end

%% Import model based results

[LE_mod, LE_V_mod, E_mod, E_V_mod, LW_mod, LW_V_mod, W_mod, W_V_mod, JL_mod, JL_V_mod]=import_reg_results(1) % i=1 corresponds to baseline model
save('res_model1','LE_mod','LE_V_mod','E_mod','LW_mod','LW_V_mod','W_mod','JL_mod','JL_V_mod')

figure(1)
plot(linspace(-6,19,26),zeros(1,26),'--k')
hold
plot(linspace(-5,20,26),LW_mod,'linewidth',3)
xh=xlabel('Years Around Separation')
yh=ylabel('Log Wage - Model')
set([xh,yh],'fontweight','bold','fontsize',15);
axis([-5 20 -.2 .05])
print(strcat('C:\Users\gjarosch\Dropbox\JMP\Drafts\Draft\pics\loss_w_mod',num2str(i),'.eps'),'-depsc')
hold off


figure(2)
plot(linspace(-6,19,26),zeros(1,26),'--k')
hold
plot(linspace(-5,20,26),LE_mod,'linewidth',3)
xh=xlabel('Years Around Separation')
yh=ylabel('Log Earnings - Model')
set([xh,yh],'fontweight','bold','fontsize',15);axis([-5 20 -.7 .07])
print(strcat('C:\Users\gjarosch\Dropbox\JMP\Drafts\Draft\pics\loss_e_mod',num2str(i),'.eps'),'-depsc')
hold off

figure(3)
plot(linspace(-5,20,26),LE_mod,'g','linewidth',3)
hold
plot(linspace(-5,20,26),E_mod-1,'m','linewidth',3)
plot(linspace(-6,19,26),zeros(1,26),'--k')
xh=xlabel('Years Around Separation')
yh=ylabel('Earnings - Model')
leg=legend('Log Earnings','Levels')
set([xh,yh,leg],'fontweight','bold','fontsize',15);axis([-5 20 -.7 .07])
print(strcat('C:\Users\gjarosch\Dropbox\JMP\Drafts\Draft\pics\loss_evsle_mod',num2str(i),'.eps'),'-depsc')
hold off

figure(4)
plot(linspace(-5,20,26),LW_mod,'g','linewidth',3)
hold
plot(linspace(-5,20,26),W_mod-1,'m','linewidth',3)
plot(linspace(-6,19,26),zeros(1,26),'--k')
xh=xlabel('Years Around Separation')
yh=ylabel('Wages - Model')
leg=legend('Log Wages','Levels')
set([xh,yh,leg],'fontweight','bold','fontsize',15);
axis([-5 20 -.2 .05])
print(strcat('C:\Users\gjarosch\Dropbox\JMP\Drafts\Draft\pics\loss_wvslw_mod',num2str(i),'.eps'),'-depsc')
hold off

figure(5)
line=plot(linspace(-6,19,26),zeros(1,26),'--k')
set(get(get(line,'Annotation'),'LegendInformation'),...
    'IconDisplayStyle','off');
hold
plot(linspace(-5,20,26),LW_mod,linspace(-5,20,26),LE_mod,'--r','linewidth',3)
leg=legend('Wages','Earnings','Location','Best') 
xh=xlabel('Years Around Separation')
yh=ylabel('Log Wage and Earnings - Model')
set([xh,yh],'fontweight','bold','fontsize',15);axis([-5 20 -.7 .07])
legend('boxoff')
print(strcat('C:\Users\gjarosch\Dropbox\JMP\Drafts\Draft\pics\loss_eandw_mod',num2str(i),'.eps'),'-depsc')

hold off

figure(6)
line=plot(linspace(-6,19,26),zeros(1,26),'--k')
set(get(get(line,'Annotation'),'LegendInformation'),...
    'IconDisplayStyle','off');
hold
plot(linspace(-5,20,26),(1+LE_mod)./(1+LW_mod)-1,'b','linewidth',3)
xh=xlabel('Years Around Separation')
yh=ylabel('Employment - Model')
set([xh,yh],'fontweight','bold','fontsize',15);axis([-5 20 -.65 .05])
print(strcat('C:\Users\gjarosch\Dropbox\JMP\Drafts\Draft\pics\loss_emp_mod',num2str(i),'.eps'),'-depsc')
hold off

figure(8)
plot(linspace(-6,19,26),zeros(1,26),'--k')
hold
plot(linspace(-5,20,26),LW_mod,'b','linewidth',3)
plot(linspace(-5,20,26),LW_mod+1.96*LW_V_mod.^.5,'--k')
plot(linspace(-5,20,26),LW_mod-1.96*LW_V_mod.^.5,'--k')
xh=xlabel('Years Around Separation')
yh=ylabel('Wage - Model')
set([xh,yh],'fontweight','bold','fontsize',15);axis([-7 20 -.2 .05])
print(strcat('C:\Users\gjarosch\Dropbox\JMP\Drafts\Draft\pics\loss_w95_mod',num2str(i),'.eps'),'-depsc')
hold off

figure(9)
plot(linspace(-6,19,26),zeros(1,26),'--k')
hold
plot(linspace(-5,20,26),LE_mod,'b','linewidth',3)
plot(linspace(-5,20,26),LE_mod+1.96*LE_V_mod.^.5,'--k')
plot(linspace(-5,20,26),LE_mod-1.96*LE_V_mod.^.5,'--k')
xh=xlabel('Years Around Separation')
yh=ylabel('Earnings - Model')
set([xh,yh],'fontweight','bold','fontsize',15);axis([-7 20 -.65 .07])
print(strcat('C:\Users\gjarosch\Dropbox\JMP\Drafts\Draft\pics\loss_e95_mod',num2str(i),'.eps'),'-depsc')
hold off

figure(10)
plot(linspace(1,20,20),JL_mod(7:end),'linewidth',3)
xh=xlabel('Years Around Separation')
yh=ylabel('Risk of Separation - Model')
set([xh,yh],'fontweight','bold','fontsize',15);
axis([1 20 0 .20])
print(strcat('C:\Users\gjarosch\Dropbox\JMP\Drafts\Draft\pics\loss_jl_mod',num2str(i),'.eps'),'-depsc')
hold off 

figure(11)
plot(linspace(1,20,20),JL_mod(7:end),'linewidth',3)
hold
plot(linspace(1,20,20),JL_mod(7:end)+1.96*JL_V_mod(7:end).^.5,'--k')
plot(linspace(1,20,20),JL_mod(7:end)-1.96*JL_V_mod(7:end).^.5,'--k')
xh=xlabel('Years Around Separation')
yh=ylabel('Risk of Separation - Model')
set([xh,yh],'fontweight','bold','fontsize',15);
axis([1 20 0 .20])
print(strcat('C:\Users\gjarosch\Dropbox\JMP\Drafts\Draft\pics\loss_jl95_mod',num2str(i),'.eps'),'-depsc')
hold off 

%% Data -- Extended Results. The data come from the log files released by IAB which are manually copied into the relevant matlab files
close all
clear
load numerical_params

load('res_ext_empirical')

figure(57)
line=plot(linspace(-6,19,26),zeros(1,26),'--k')
set(get(get(line,'Annotation'),'LegendInformation'),...
    'IconDisplayStyle','off');
hold
plot(linspace(-5,20,26),LW_FE,'k',linspace(-5,20,26),LE_FE,'--k','linewidth',3)
plot(linspace(-5,20,26),LE_FE+1.96*LE_FE_V.^.5,'--k')
plot(linspace(-5,20,26),LE_FE-1.96*LE_FE_V.^.5,'--k')
plot(linspace(-5,20,26),LW_FE+1.96*LW_FE_V.^.5,'k')
plot(linspace(-5,20,26),LW_FE-1.96*LW_FE_V.^.5,'k')
leg=legend('Wages','Earnings','Location','SouthEast') 
xh=xlabel('Years Around Separation')
yh=ylabel('% Change Wage and Earnings - Data')
set([xh,yh],'fontweight','bold','fontsize',15);
axis([-5 20 -.6 .07])
legend('boxoff')
print(strcat('C:\Users\gjarosch\Dropbox\JMP\Drafts\Draft\pics\loss_eandwFE95_alt_data1.eps'),'-depsc')
hold off




%% Model vs Data
clear
close all
%baseline, empirical and model
load('res_empirical1')
load('res_model1')
%addtional regressions from file regressions_xtnd
%import_reg_results_ext
load('res_ext')
load('res_ext_empirical')

figure(1)
subplot(2,1,1)
plot(linspace(-5,20,26),LE_Q10,'-+b',linspace(-5,20,26),LE_Q25,'-.b',linspace(-5,20,26),LE_Q50,'b',linspace(-5,20,26),LE_Q75,'-.b',linspace(-5,20,26),LE_Q90,'-+b','linewidth',1)
hold
plot(linspace(-5,20,26),zeros(1,26),'--k')
yh=ylabel('Log Earnings')
tit=title('Data')
set([yh,tit],'fontweight','bold','fontsize',13);
axis([-5,20,-1.3,.15])
subplot(2,1,2)
plot(linspace(-5,20,26),LE_Q10_mod,'-+r',linspace(-5,20,26),LE_Q25_mod,'-.r',linspace(-5,20,26),LE_Q50_mod,'r',linspace(-5,20,26),LE_Q75_mod,'-.r',linspace(-5,20,26),LE_Q90_mod,'-+r','linewidth',1)
hold
plot(linspace(-5,20,26),zeros(1,26),'--k')
axis([-5,20,-1.3,.15])
tit=title('Model')
xh=xlabel('Years Around Separation')
yh=ylabel('Log Earnings')
leg=legend('10th','25th','Median','75th','90th','Location','SouthEast')
set([xh,yh,tit,leg],'fontweight','bold','fontsize',13);
set(leg,'NumColumns',2)
print('C:\Users\gjarosch\Dropbox\JMP\Drafts\Draft\pics\loss_equant_datmodel.eps','-depsc')
hold off

figure(2)
subplot(2,2,2)
plot(linspace(-5,20,26),LW,'-.b','linewidth',3)
hold
plot(linspace(-5,20,26),LW_mod,'r','linewidth',3)
plot(linspace(-6,19,26),zeros(1,26),'--k')
xh=xlabel('Years Around Separation')
yh=ylabel('Log Wage')
%leg=legend('Data','Model')
set([xh,yh],'fontweight','bold','fontsize',10);
axis([-5 20 -.25 .05])
hold off

subplot(2,2,1)
plot(linspace(-5,20,26),LE,'-.b','linewidth',3)
hold
plot(linspace(-5,20,26),LE_mod,'r','linewidth',3)
plot(linspace(-6,19,26),zeros(1,26),'--k')
xh=xlabel('Years Around Separation')
yh=ylabel('Log Earnings')
leg=legend('Data','Model', 'Location','SouthEast')
set([xh,yh,leg],'fontweight','bold','fontsize',10);
set([leg],'fontweight','bold','fontsize',13);
axis([-5 20 -.7 .05])
hold off

subplot(2,2,3)
line=plot(linspace(-6,19,26),zeros(1,26),'--k')
set(get(get(line,'Annotation'),'LegendInformation'),...
    'IconDisplayStyle','off');
hold
plot(linspace(-5,20,26),(1+LE)./(1+LW)-1,'-.b','linewidth',3)
plot(linspace(-5,20,26),(1+LE_mod)./(1+LW_mod)-1,'r','linewidth',3)
xh=xlabel('Years Around Separation')
yh=ylabel('Employment')
%leg=legend('Data','Model', 'Location','SouthEast')
set([xh,yh],'fontweight','bold','fontsize',10);
axis([-5 20 -.7 .05])
hold off

subplot(2,2,4)
plot(linspace(-5,20,26),JL,'-.b','linewidth',3)
hold
plot(linspace(-5,20,26),JL_mod,'r','linewidth',3)
xh=xlabel('Years Around Separation')
yh=ylabel('Risk of Separation')
%leg=legend('Data','Model')
set([xh,yh],'fontweight','bold','fontsize',10);
axis([1 20 0 .15])
hold off 

print(strcat('C:\Users\gjarosch\Dropbox\JMP\Drafts\Draft\pics\loss_datamodel.eps'),'-depsc')

figure(3)
plot(linspace(-5,20,26),LE,'b','linewidth',3)
hold
plot(linspace(-5,20,26),LE_mod,'--r','linewidth',3)
plot(linspace(-6,19,26),zeros(1,26),'--k')
xh=xlabel('Years Around Separation')
yh=ylabel('Log Earnings')
leg=legend('Data','Model', 'Location','SouthEast')
set([xh,yh,leg],'fontweight','bold','fontsize',15);
axis([0 20 -.75 .05])
print(strcat('C:\Users\gjarosch\Dropbox\JMP\Drafts\Draft\pics\loss_e_datamodel.eps'),'-depsc')

hold off


figure(5)
plot(linspace(-5,20,26),LE_Q10,'-+b',linspace(-5,20,26),LE_Q25,'-.b',linspace(-5,20,26),LE_Q50,'b',linspace(-5,20,26),LE_Q75,'-.b',linspace(-5,20,26),LE_Q90,'-+b','linewidth',2)
hold
plot(linspace(-5,20,26),LE_Q10_mod,'-+r',linspace(-5,20,26),LE_Q25_mod,'-.r',linspace(-5,20,26),LE_Q50_mod,'r',linspace(-5,20,26),LE_Q75_mod,'-.r',linspace(-5,20,26),LE_Q90_mod,'-+r','linewidth',2)
plot(linspace(-5,20,26),zeros(1,26),'--k')
yh=ylabel('Log Earnings')
axis([-5,20,-1.3,.15])
xh=xlabel('Years Around Separation')
yh=ylabel('Log Earnings')
leg=legend('10th','25th','Median','75th','90th','Location','SouthEast')
set([xh,yh,tit,leg],'fontweight','bold','fontsize',13);
set(leg,'NumColumns',2)
print('C:\Users\gjarosch\Dropbox\JMP\Drafts\Draft\pics\loss_equant_datmod2.eps','-depsc')
hold off

figure(5)
plot(linspace(-5,20,26),LE_Q10,'-+k',linspace(-5,20,26),LE_Q25,'-.k',linspace(-5,20,26),LE_Q50,'k',linspace(-5,20,26),LE_Q75,'-.k',linspace(-5,20,26),LE_Q90,'-+k','linewidth',2)
hold
plot(linspace(-5,20,26),zeros(1,26),'--k')
yh=ylabel('Log Earnings')
axis([-5,20,-1.3,.15])
xh=xlabel('Years Around Separation')
yh=ylabel('Log Earnings')
leg=legend('10th','25th','Median','75th','90th','Location','SouthEast')
set([xh,yh,tit,leg],'fontweight','bold','fontsize',13);
set(leg,'NumColumns',2)
print('C:\Users\gjarosch\Dropbox\JMP\Drafts\Draft\pics\loss_equant_dat.eps','-depsc')
hold off

%% imports the results from the modified model with no heterogeneity and contrasts it with the main model results.
clear all
close 

[LE_mod, LE_V_mod, E_mod, E_V_mod, LW_mod, LW_V_mod, W_mod, W_V_mod, JL_mod, JL_V_mod]=import_reg_results(2) % i=1 corresponds to baseline model
save('res_model2','LE_mod','LE_V_mod','E_mod','LW_mod','LW_V_mod','W_mod','JL_mod','JL_V_mod')

LE_mod_alt=LE_mod;
LW_mod_alt=LW_mod;
JL_mod_alt=JL_mod;

[LE_mod, LE_V_mod, E_mod, E_V_mod, LW_mod, LW_V_mod, W_mod, W_V_mod, JL_mod, JL_V_mod]=import_reg_results(1) % i=1 corresponds to baseline model

figure(1)
subplot(1,3,1)
plot(linspace(-5,20,26),LE_mod,linspace(-5,20,26),LE_mod_alt,'--','linewidth',2)
hold
plot(linspace(-5,20,26),zeros(1,26),'--b')
yh=ylabel('Earnings')
set([yh],'fontweight','bold','fontsize',10);
axis([-1 20 -.75 .01])
hold off

subplot(1,3,2)
plot(linspace(-5,20,26),LW_mod,linspace(-5,20,26),LW_mod_alt,'--','linewidth',2)
hold
plot(linspace(-5,20,26),zeros(1,26),'--b')
yh=ylabel('Wages')
leg=legend('Baseline','$\theta_{\delta}=\bar{\theta}_{\delta}$','Location','South','Interpreter','latex')
set([yh,leg],'fontweight','bold','fontsize',10);
axis([-1 20 -.75 .01])
hold off

subplot(1,3,3)
plot(linspace(-5,20,26),(1+LE_mod)./(1+LW_mod)-1,linspace(-5,20,26),(1+LE_mod_alt)./(1+LW_mod_alt)-1,'--','linewidth',2)
hold
plot(linspace(-5,20,26),zeros(1,26),'--b')
yh=ylabel('Employment')
set([yh],'fontweight','bold','fontsize',10);
axis([-1 20 -.75 .01])
hold off
print('C:\Users\gjarosch\Dropbox\JMP\Drafts\Draft\pics\loss_no_het_d.eps','-depsc')


[LE_mod, LE_V_mod, E_mod, E_V_mod, LW_mod, LW_V_mod, W_mod, W_V_mod, JL_mod, JL_V_mod]=import_reg_results(3) % i=1 corresponds to baseline model
save('res_model3','LE_mod','LE_V_mod','E_mod','LW_mod','LW_V_mod','W_mod','JL_mod','JL_V_mod')

LE_mod_alt=LE_mod;
LW_mod_alt=LW_mod;
JL_mod_alt=JL_mod;

[LE_mod, LE_V_mod, E_mod, E_V_mod, LW_mod, LW_V_mod, W_mod, W_V_mod, JL_mod, JL_V_mod]=import_reg_results(1) % i=1 corresponds to baseline model


figure(2)
subplot(1,3,1)
plot(linspace(-5,20,26),LE_mod,linspace(-5,20,26),LE_mod_alt,'--','linewidth',2)
hold
plot(linspace(-5,20,26),zeros(1,26),'--b')
yh=ylabel('Earnings')
set([yh],'fontweight','bold','fontsize',10);
axis([-1 20 -.75 .01])
hold off

subplot(1,3,2)
plot(linspace(-5,20,26),LW_mod,linspace(-5,20,26),LW_mod_alt,'--','linewidth',2)
hold
plot(linspace(-5,20,26),zeros(1,26),'--b')
yh=ylabel('Wages')
leg=legend('Baseline','$s=\bar{s}$','Location','South','Interpreter','latex')
set([yh,leg],'fontweight','bold','fontsize',10);
axis([-1 20 -.75 .01])
hold off

subplot(1,3,3)
plot(linspace(-5,20,26),(1+LE_mod)./(1+LW_mod)-1,linspace(-5,20,26),(1+LE_mod_alt)./(1+LW_mod_alt)-1,'--','linewidth',2)
hold
plot(linspace(-5,20,26),zeros(1,26),'--b')
yh=ylabel('Employment')
set([yh],'fontweight','bold','fontsize',10);
axis([-1 20 -.75 .01])
hold off

print('C:\Users\gjarosch\Dropbox\JMP\Drafts\Draft\pics\loss_no_het_s.eps','-depsc')

close all
