%%%% GMM standard errors for the parameter estimates

clear all
close all
clc
 
rng('default')
 
load omega
load mom_targ
load numerical_params
load n_mom 
load v_mom
% note: for variance of last moment, to be conservative, assigned as
% variance of uniform random variable on [0.5,1] (the target is .75);
load best_params722
params=[lam0 lam1 alph up down by1 by2 bd1 bd2 thet ymin z];

% construct parameter perturbations. i have experimented with the perturb matrix to take into account
% constraints and local simulation noise
for ii=1:12
lam0t=lam0*(1+perturb(1)*(ii==1));
lam1t=lam1*(1+perturb(2)*(ii==2));
alpht=alph*(1-perturb(3)*(ii==3));
upt=up*(1+perturb(4)*(ii==4));
downt=down*(1+perturb(5)*(ii==5));
by1t=by1*(1+perturb(6)*(ii==6));
by2t=by2*(1+perturb(7)*(ii==7));
bd1t=bd1*(1+perturb(8)*(ii==8));
bd2t=bd2*(1+perturb(9)*(ii==9));
thett=thet*(1+perturb(10)*(ii==10));
ymint=ymin*(1+perturb(11)*(ii==11));
zt=z*(1+perturb(12)*(ii==12));

params_ste(ii,:)=[lam0t lam1t alpht upt downt by1t by2t bd1t bd2t thett ymint zt];
end

% recompute all moments for each of the perturbations
parfor ii=1:12

lam0=params_ste(ii,1);
lam1=params_ste(ii,2);
alph=params_ste(ii,3);
up=params_ste(ii,4);
down=params_ste(ii,5);
by1=params_ste(ii,6);
by2=params_ste(ii,7);
bd1=params_ste(ii,8);
bd2=params_ste(ii,9);
thet=params_ste(ii,10);
ymin=params_ste(ii,11);
z=params_ste(ii,12)

[dn,ytil]=copula_new(by1,by2,bd1,bd2,thet,groups);
yn=ymin+ytil;
[Sxv2,w,WU,rs]= values_full_with_u(dn,yn,bet,lam0,lam1,alph,nx,nf,x,up,down,z,by1,by2,bd1,bd2,thet,ymin);
[stat, firm, hc, wage, firmp, workerp, espell, jspell, uspell, bench, hcneg]=dataset_only_extended(Sxv2,w,WU,dn,yn,bet,lam0,lam1,alph,ny,nx,nd,nf,x,up,down,z,T,N,rs);
[mom_est] =moments(stat, firm, hc, wage, espell, jspell, uspell,N,T,lam1, z,yn,x)
LL = sum((log(mom_targ./mom_est)).^2./omega,2) 

chains_ste(ii,:)=[lam0 lam1 alph up down by1 by2 bd1 bd2 thet ymin z mom_est LL];
end

% compute moments once under the "point estimate"
load best_params722

[dn,ytil]=copula_new(by1,by2,bd1,bd2,thet,groups);
yn=ymin+ytil;
[Sxv2,w,WU,rs]= values_full_with_u(dn,yn,bet,lam0,lam1,alph,nx,nf,x,up,down,z,by1,by2,bd1,bd2,thet,ymin);
[stat, firm, hc, wage, firmp, workerp, espell, jspell, uspell, bench, hcneg]=dataset_only_extended(Sxv2,w,WU,dn,yn,bet,lam0,lam1,alph,ny,nx,nd,nf,x,up,down,z,T,N,rs);
[mom_est] =moments(stat, firm, hc, wage, espell, jspell, uspell,N,T,lam1, z,yn,x);

% putting it together to get the standard errors

W=diag(1./omega); %weighting matrix used in estimation
S=diag((1./mom_targ).^2.*v_mom); % variance of moments. i use a taylor expansion to go from variants of targets in levels (v_mom, computed in the data) to variance of targets in logs
% next just build a MxK gradient matrix that records how each moment moves
% as we perturb each parameter around point estimate
grad=((log(chains_ste(:,13:26)./repmat(mom_targ,12,1))-repmat(log(mom_est./mom_targ),12,1))./repmat((params.*perturb')',1,14))';
GW=grad'*W;
GWG=GW*grad;
gmm_ste=(diag((GWG\(GW*S*GW'))/GWG)).^.5 % note I use the smallest number of n going into the calculation of any moment

save ste gmm_ste
    