* File of the Project "PROJECTNAMET" - 2_gen_cr_sect.do
* Content: Generate cross sectional data - Code is directly from Eberle, Schmucker, and Seth from IAB webpage
			* Append Monthly Cross Section to Generate Monthly Panel


/*------------------------------------------------------------------------------------------------*\
  GENERATE CROSS-SECTIONS AT REFERENCE DATES
\*------------------------------------------------------------------------------------------------*/

clear
*set mem 50g
set more off
cap log close

log using "$log/2_gen_cross_sect.log", replace

*-----------------------------*
* MAKE CROSS-SECTIONS         *
*-----------------------------*
use "$data/bio.dta"


global cutoff "01-31 02-28 03-31 04-30 05-31 06-30 07-31 08-31 09-30 10-31 11-30 12-31"	// Insert reference dates as "mm-dd", use spaces
global firstyear "1975"
global lastyear "2010"
global years 1975/2010	// Insert years as numlist

* Reduce the Size of the Sample
/*
by persnr: gen sample=runiform() if _n==1
by persnr: egen sample2=max(sample)
count
keep if sample2<.1
count
drop sample sample2
*/

* LOOP OVER SPECIFIED YEARS AND REFERENCE DATES
foreach y of numlist $years {
	foreach c of global cutoff {
		scalar cdate = date("`c'-`y'", "MDY")

		* PRESERVE DATA SET AND USE IT IN EVERY LOOP
		preserve

		* SELECT OBSERVATIONS THAT OVERLAP THE REFERENCE DATE
		keep if begepi <= cdate & endepi >= cdate

		* NUMBER OF PARALLEL OBSERVATIONS PER REFERENCE DATE
		tab level2

		* NUMBER OF PARALLEL OBSERVATIONS OF A SOURCE PER REFERENCE DATE
		tab level1

		* INFORMATION ON 1st SECONDARY EMPLOYMENT (quelle == 1 & level1 ==1)
		* Full-time secondary employment
		* Part-time secondary employment liable to social security
		* Marginal secondary employment
		* secondary employment not specified
		gen     nb1 =  1 if inlist(stib, 0, 1, 2, 3, 4, 5, 6, 7)     & level1 == 1
		replace nb1 =  2 if inlist(stib, 8, 9)                       & level1 == 1
		replace nb1 =  3 if inlist(erwstat, 109, 110, 202, 209, 210) & level1 == 1
		replace nb1 =  4 if erwstat == .z | stib == .z		     & level1 == 1 & nb1 == .

		* INFORMATION ON PARALLEL OBSERVATIONS OF OTHER SOURCES
                gen leh1 = quelle ==  2 	       & level2 != 0 	// don't count main observation
		gen asu1 = quelle ==  7 | quelle == 18 & level2 != 0	// don't count main observation
		gen lhg1 = quelle == 16 | quelle == 19 & level2 != 0	// don't count main observation

		* COPY INFORMATION ON PARALLEL OBSERVATIONS TO ALL OBSERVATIONS OF THE INDIVIDUAL
		bysort persnr: egen nb  = max(nb1)
                replace nb = .n if nb == .
		bysort persnr: egen leh = max(leh1)
		bysort persnr: egen asu = max(asu1)
		bysort persnr: egen lhg = max(lhg1)

		* DELETE THE AUXILIARY VARIABLES
		drop nb1 leh1 asu1 lhg1

		* SECONDARY EMPLOYMENT IN SAME ESTABLISHMENT
		sort persnr level2 level1
		gen nb_betr = betnr == betnr[_n+1] if persnr == persnr[_n+1] & level2 ==0 & quelle ==1 & !missing(betnr)
		recode nb_betr (.= 0) if nb == 1
		recode nb_betr (.= .z) if quelle[_n+1] == 1
		recode nb_betr (.= .n)

		* TOTAL INCOME OF ALL JOBS AND BENEFIT RECEIPTS:
		bysort persnr: egen gtentgelt = total(tentgelt)

		* KEEP MAIN OBSERVATION
		keep if level2 == 0

		* DATE VARIABLE OF REFERENCE DATE
		gen stichtag = cdate
		format stichtag %td

		* LABEL NEW VARIABLES
		label language en
		label define nb_en 1 "1  full-time job" 2 "2  part-time job" 3 "3  marginal part-time job" 4 "4  not specified second job" .z ".z  no entry" .n ".n  n/a"
		label values nb nb_en
		label variable nb         "Type of second job"
		label variable leh        "Parallel observation: LeH"
		label variable asu        "Parallel observation: (X)ASU"
		label variable lhg        "Parallel observation: (X)LHG"
		label define nb_betr_en 0 "0  other establishment" 1 "1  same establishment" .z ".z  no entry" .n ".n  n/a"
		label values nb_betr nb_betr_en
		label variable nb_betr	  "Secondary employment in same establishment as main occupation"
		label variable gtentgelt  "Total income, all sources"
		label variable stichtag   "Reference date of the cross section"

		label language de
		label define nb_de 1 "1  Vollzeit-Job" 2 "2  Teilzeit-Job" 3 "3  geringfügige Beschäftigung" 4 "4  Nebenjob ohne nähere Angaben" .z ".z  k. Angabe" .n ".n  fehlt syst."
		label values nb nb_de
		label variable nb         "Art der Nebenbeschäftigung"
		label variable leh        "Gleichzeitige Beobachtung LeH"
		label variable asu        "Gleichzeitige Beobachtung (X)ASU"
		label variable lhg        "Gleichzeitige Beobachtung (X)LHG"
		label define nb_betr_de 0 "0  anderer Betrieb" 1 "1  gleicher Betrieb" .z ".z  k. Angabe" .n ".n  fehlt syst."
		label values nb_betr nb_betr_de
		label variable nb_betr	  "Nebenbeschäftigung im Betrieb der Hauptbeschäftigung"
		label variable gtentgelt  "Gesamteinkommen aus allen Quellen"
		label variable stichtag   "Stichtag des Querschnitts"

		foreach var of varlist nb leh asu lhg {

			label language en
			lab def `var'_en 0 "0  no" 1 "1  yes" .n ".n  n/a" .z ".z  no entry", add modify
			lab val `var' `var'_en
			numlabel `var'_en, add mask("#  ")

			label language de
			lab def `var'_de 0 "0  nein" 1 "1  ja" .n ".n  fehlt syst." .z ".z  k. Angabe", add modify
			lab val `var' `var'_de
			numlabel `var'_de, add mask("#  ")
			}

		foreach var of varlist gtentgelt stichtag {

			label language en
			lab def `var'_en  .n ".n  n/a" .z ".z  no entry", add modify
			lab val `var' `var'_en
			numlabel `var'_en, add mask("#  ")

			label language de
			lab def `var'_de .n ".n  fehlt syst." .z ".z  k. Angabe", add modify
			lab val `var' `var'_de
			numlabel `var'_de, add mask("#  ")
			}

		* DURATION VARIABLES OFF AT REFERENCE DATE
		replace tage_erw = tage_erw - (endepi - cdate) if quelle ==1 & stib != 0
		replace tage_bet = tage_bet - (endepi - cdate) if quelle ==1 & !missing(tage_bet)
		replace tage_job = tage_job - (endepi - cdate) if quelle ==1 & !missing(tage_job)
		replace tage_lst = tage_lst - (endepi - cdate) if  inlist(quelle, 2, 16, 19)
		replace tage_lst = tage_lst - (endepi - cdate) if !inlist(quelle, 2, 16, 19) & (leh ==1 | lhg ==1)

		* DROP OBSOLETE VARIABLES
		drop spell level2 level1

		gen year =`y'

keep persnr betnr quelle stib erwstat begorig begepi endorig endepi tentgelt tage* ein* stichtag gebjahr erwstat stichtag beruf frau bild wo_bula

compress

		* SAVE CROSS-SECTION DATA SET
		save "$data/`c'`y'.dta", replace

		* RELOAD PRESERVED DATA
		restore
	}
}


clear
foreach y of numlist $years {
	foreach c of global cutoff {
	quietly append using "$data/`c'`y'.dta"

	}
		display `y'
	}
compress
save "$data/monthly.dta", replace


foreach y of numlist $years {
	foreach c of global cutoff {
	erase "$data/`c'`y'.dta"
	}
	}


*log close
*clear all









