* take monthly data set, generate indicators for job loss, measure tenure, create various additional variables (not all used later), drop outliers, save as additional monthly dataset

clear
*set max_memory 50g
cap log close

log using "$log/4_data_annual.log", replace

use "$data/monthly.dta", clear

set seed 123456789

bys persnr: gen sample=runiform() if _n==1
bys persnr: egen sample2=max(sample)
count
keep if sample2<1	
count
drop sample sample2


gen calmn=month(stichtag)
gen calyr=year(stichtag)
gen caldate=mofd(stichtag)
tsset persnr caldate, monthly

**************************************************
* generate indicators for job loss *
**************************************************

*employed only if employed subject to social security and not part time
gen emp=(erwstat==101 & stib!=8 & stib!=9)

* primeage workers between 25 and 54
gen age= calyr - gebjahr
tab age if emp==1
keep if age<66 & age>17

* jobloss if employment ends
bysort persnr: gen jobloss=(emp[_n]==1 & emp[_n+1]==0)
sum jobloss if emp==1

* jobloss into ue if employment ends and move into ui system (within three months)
bysort persnr: gen jobloss_ue=(emp[_n]==1 & emp[_n+1]==0 & (erwstat[_n+1]<3 | (emp[_n+2]==0 & erwstat[_n+2]<3 | (emp[_n+2]==0 & emp[_n+3]==0 & erwstat[_n+3]<3))))
sum jobloss_ue if emp==1

**************************************************
* generate tenure variables
**************************************************

*** measure tenure on the job and time since last non-employment spell (eten)
gen jobloss_ten2=0
gen jobloss_ten_ue2=0
bysort persnr: gen jobtojob=(emp[_n]==1 & emp[_n+1]==1 & stichtag[_n+1]-stichtag[_n]<=32 & betnr[_n]!=betnr[_n+1])
bysort persnr: gen eten=(emp[_n]==1 & emp [_n-1]!=1)
bysort persnr: replace eten=1 if emp[_n]==1 & emp[_n-1]==1 & jobloss[_n-1]==1
bysort persnr: gen jten=eten
bysort persnr: replace jten=1 if jobtojob[_n-1]==1
bysort persnr: replace eten=eten[_n-1]+1 if (emp[_n]==1 & emp[_n-1]==1 & stichtag[_n]-stichtag[_n-1]<=62)
bysort persnr: replace jten=jten[_n-1]+1 if (emp[_n]==1 & emp[_n-1]==1 & stichtag[_n]-stichtag[_n-1]<=62 & jobtojob[_n-1]!=1)

*** Apply pre-separation tenure restriction
bys persnr: replace jobloss_ten2 =1 if (jobloss[_n]==1 & jten[_n]>=36)
bys persnr: replace jobloss_ten_ue2 =1 if (jobloss_ue[_n]==1 & jten[_n]>=36)
replace jobloss_ten_ue2=.n if emp~=1
replace jobloss_ten2=.n if emp~=1


*********************************************************************
* generate average wages and earnings and total employment and number of joblosses
*********************************************************************
*average wage during full time employment
bys persnr calyr: egen avw=mean(tentgelt) if(emp==1 & stib!=8 & stib!=9)

*average renumeration during full or part-time employment
bys persnr calyr: egen avw_b=mean(tentgelt) if(emp==1 | erwstat==109)

* earnings during months of full time employment
bys persnr calyr: egen ave=sum(tentgelt) if (emp==1& stib!=8 & stib!=9)
replace ave=ave/12

* earnings during months full and part-time employment
bys persnr calyr: egen ave_b=sum(tentgelt) if (emp==1 | erwstat==109)
replace ave_b=ave_b/12

*** Merge Price Index and compute real wages and earnings
merge n:1 calyr using "$orig/cpi2000_oecd.dta", nogenerate
replace avw=avw/cpi
replace ave=ave/cpi
replace avw_b=avw_b/cpi
replace ave_b=ave_b/cpi


* outliers

local pay "avw ave avw_b ave_b"
foreach p of local pay {
replace `p'=. if `p'==0
replace `p'=.n if `p'==.
foreach yy of numlist 1975/2010{
centile `p' if calyr==`yy', centile(1 99.9)
local lower=r(c_1)
local upper=r(c_2)
replace `p'=`lower' if `p'<`lower' & `p'!=.n & calyr==`yy'
replace `p'=`upper' if `p'>`upper' & `p'!=.n & calyr==`yy'
}
}


compress
drop beg* end* wo_b* quelle ein_erw ein_bet tage_lst cpi* ein_job

d
tsset persnr caldate, monthly

*******************************************************************************
********************* A Few Additional Variables to Construct
*******************************************************************************

** count employment tenure, jobtenure unemployment duration and keep track of last employer and wage at last employer
bysort persnr: gen dateofloss=stichtag if jobloss==1
bysort persnr: replace dateofloss=dateofloss[_n-1] if emp==0
bysort persnr: gen dateofloss_ue=stichtag if jobloss_ue==1
bysort persnr: replace dateofloss_ue=dateofloss_ue[_n-1] if emp==0
bysort persnr: gen udur=round((stichtag-dateofloss[_n-1]-1)/30) if eten==1
bysort persnr: gen udur_ue=round((stichtag-dateofloss_ue[_n-1]-1)/30) if eten==1

* indicator for those who enter the database with *spell not zero
sum caldate
local md=r(min)
* indicate if someone is employed when the database begins (dont know tenure for these spells)
bysort persnr: gen start_ind= 1 if eten[1]!=0 & caldate==`md'
bysort persnr: replace start_ind=0 if _n!=1
bysort persnr: replace start_ind=start_ind[_n-1]*1 if (eten[_n]!=0 & _n!=1 & jobtojob[_n-1]!=1)
* now change every starting *spell to missing
bysort persnr: replace eten=. if (start_ind==1 & jobloss==0) | (eten[_n-1]==. & emp[_n]==1 & jobloss[_n-1]==0) | (jobloss==1 & _n==1 & start_ind==1)
bysort persnr: replace jten=. if start_ind==1
bysort persnr: replace jten=. if  (betnr[_n]!=betnr[_n+1] & start_ind[_n-1]==1)

******************************************************
********* Additional Variables Needed for Momens
*****************************************************

gen logwage=ln(avw) if emp==1
bysort persnr: egen meanwage=mean(logwage) if emp==1
bysort persnr: egen meansep=mean(jobloss) if emp==1
bysort persnr: egen meansep_ue=mean(jobloss_ue) if emp==1

* separation rate at employer level
bysort betnr: egen firm_sep=mean(jobloss)
bysort betnr: egen firm_sep_ue=mean(jobloss_ue)

sort persnr caldate
compress

drop start_ind dateof* 

d
tsset persnr caldate

save "$data/monthly.dta", replace
