* File of the Project "670" - 52_deltas.do
* Content: compute heterogeneity in terms of separations into unemployment across firms
* The File produces 4 lists, for four histogram. The first column reports the number of observations entering each "bar"
* The second list corresponds to the first exercise in section 3.5 in the paper. the first list corresponds to the second exercise. rest unused

clear

cap log close
log using "$log/51_firm_delta.log", replace

set more off

local simul=1
 // turn to 1 for simulated data, otherwise 0

**************************************************************
*************** Constructing Data on Monthly Firm Level Churn
**************************************************************
use "$data/monthly.dta", replace
if `simul'==1{
use "$simul/monthly_simul.dta", replace
}

quietly{
*****************************************************************************
************ Exercise 1: Regress individual separations on a set of fixed effects, residualize, and project on firms -> m_resi_ue is average at the firm level
***************************************************************************

reghdfe avw, a(persnr calyr) res(resi_w)
reghdfe jobloss_ue, a(persnr calyr) res(resi_ue)
reghdfe jobloss, a(persnr calyr) res(resi_u)

gen cc=1
// collapse by firm and calyr: then, resi_ue has the residualized unemployment risk at the firm-year level (same for resi_w...)
collapse jobloss* avw resi_u* resi_w (sum) betemp=cc, by(betnr calyr)

bys betnr: egen m_resi_ue=mean(resi_ue)
bys betnr: egen m_resi_u=mean(resi_u)
bys betnr: egen m_resi_w=mean(resi_w)

sum m_resi_u* [fw=betemp], det
sum m_resi_u* if betemp>50 [fw=betemp], det

display "Churn Histogram -- Average Residual Firm Level Separation Rate"
*hist m_resi_ue [fw=betemp]
twoway__histogram_gen m_resi_ue if m_resi_ue>-.15 & m_resi_ue<.15 [fw=betemp], gen(n_obs bin_fre2) bin(50) frequency
twoway__histogram_gen m_resi_ue if m_resi_ue>-.15 & m_resi_ue<.15 [fw=betemp], gen(dens x) bin(50) dens
noi display _newline "List for Histogram - Average Residual Firm Level Separation Rate "
noi list n_obs dens bin_fre2 if bin_fre2~=., clean N(bin_fre2)
drop n_obs bin_fre2 dens x

*****************************************************************************
************ Exercise 2: Firm Fixed Effect
***************************************************************************

gen del2_ue=jobloss_ue
gen del2_u=jobloss

* firm fe (shedding workers to ue)
reghdfe del2_ue, a(betnr) res(res_del_ue)
gen chi_ue=del2_ue-res_del_ue
sum chi_ue [fw=betemp], det
sum chi_ue if betemp > 50 [fw=betemp], det
sum chi_ue if chi_ue>0 [fw=betemp], det

display "Churn Histogram -- Firm FE"
*hist chi_ue [fw=betemp]
twoway__histogram_gen chi_ue if chi_ue<.25 [fw=betemp], gen(n_obs bin_fre2) bin(50) frequency
twoway__histogram_gen chi_ue if chi_ue<.25 [fw=betemp], gen(dens x) bin(50) dens
noi display _newline "List for Histogram - Avg Firm Level Sep Rate"
noi list n_obs dens bin_fre2 if bin_fre2~=., clean N(bin_fre2)
drop n_obs bin_fre2 dens x

/*
display "Churn Histogram -- Firm FE, Large Firms Only"
*hist chi_ue [fw=betemp]
twoway__histogram_gen chi_ue if betemp > 50 & chi_ue<.25 [fw=betemp], gen(n_obs bin_fre2) bin(50) frequency
twoway__histogram_gen chi_ue if betemp > 50 & chi_ue<.25 [fw=betemp], gen(dens x) bin(50) dens
noi display _newline "List for Histogram - Avg Firm Level Sep Rate, Large Firms Only"
noi list n_obs dens bin_fre2 if bin_fre2~=., clean N(bin_fre2)
drop n_obs bin_fre2 dens x
*/

display "Churn Histogram -- Firm FE, Positive Obs Only"
*hist chi_ue [fw=betemp]
twoway__histogram_gen chi_ue if chi_ue>0 & chi_ue<.25 [fw=betemp], gen(n_obs bin_fre2) bin(50) frequency
twoway__histogram_gen chi_ue if chi_ue>0 & chi_ue<.25 [fw=betemp], gen(dens x) bin(50) dens
noi display _newline "List for Histogram - Avg Firm Level Sep Rate, Pos Values Only"
noi list n_obs dens bin_fre2 if bin_fre2~=., clean N(bin_fre2)
drop n_obs bin_fre2 dens x


* same thing but with u instead of ue
reghdfe del2_u, a(betnr) res(res_del_u)
gen chi_u=del2_u-res_del_u
sum chi_u [fw=betemp], det
sum chi_u if betemp>50 [fw=betemp], det
sum chi_u if chi_u>0 [fw=betemp], det

merge n:1 calyr betnr using "$data/masslayoff.dta" // just to get the firm wage variable
drop if _merge==2
drop _merge

gen dur=lzt_jahr-grd_jahr

if `simul'==0{
* same thing but only for firms at least 18 years old
reghdfe del2_ue if dur>19, a(betnr) res(res_del_ue_d)
gen chi_ue_d=del2_ue-res_del_ue_d
sum chi_ue_d [fw=betemp], det
sum chi_ue_d if betemp>50 [fw=betemp], det
sum chi_ue_d if chi_ue_d>0 [fw=betemp], det
}

if `simul'==1{
gen chi_ue_d=chi_ue
}

display "Churn Histogram -- Firm FE, Positive Obs Only"
*hist chi_ue [fw=betemp]
twoway__histogram_gen chi_ue_d  if chi_ue<.25 [fw=betemp], gen(n_obs bin_fre2) bin(50) frequency
twoway__histogram_gen chi_ue_d  if chi_ue<.25 [fw=betemp], gen(dens x) bin(50) dens
noi display _newline "List for Histogram - Avg Firm Level Sep Rate, Old Firms Only"
noi list n_obs dens bin_fre2 if bin_fre2~=., clean N(bin_fre2)
drop n_obs bin_fre2 dens x


label var chi_ue "firm separation rate into ue fe"
label var chi_u "firm separation rate into u fe"
label var chi_ue_d "firm separation rate into ue fe, only old firms"
label var m_resi_ue "residualized firm level separation rate"

compress

save "$data/firm_delta.dta", replace

}
