* File of the Project "670" - 53_perm_trans.do
* Content: estimates a permanent-transitory component model for unemployment risk at the firm level
* The variable being fitted is unemployment risk at the firm level
* The file does this once for a simple baseline model and then twice in addition for a model that allows for firm age-specific effects.
* Final ouput: For all models prints the table with parameter estimates and, separately, the variance of the permanent component. 
* Number of Observations used can be seen at the first table after convergence

clear

cap log close

log using "$log/52_perm_trans.log", replace

set more off

set seed 123456789

local simul=1

quietly{

*************************************************************************************************************************
*********** 1) BASELINE CASE, MODEL 1. NO EXPERIENCE VARIABLE
*************************************************************************************************************************

use "$data/firm_delta.dta", replace
local ny=36

keep del2_ue betemp grd_jahr calyr betnr

// clean up
count if betnr==.
count
drop if betnr==.
drop if betnr==.n
drop if betnr==.z

// just replace the strings with id=1,2,...N
egen bet2=group(betnr)
replace betnr=bet2

// the next block duplicates firms based on size (as a means of weighting). first step, express employment relative to smallest employer (does nothing in the data)
sum betemp, det
local minsz=r(min)
replace betemp=betemp/`minsz'

// duplicates observations according to betemp. this does the weighting
expand betemp 

// next block treats the duplicates as separate firms with different firm-id
bys betnr calyr: gen long grr=_n
egen long tgt=tag(betnr grr)
sort betnr grr calyr
gen long betnr_n=sum(tgt)

// drops duplicate firm-year observations
duplicates tag betnr_n calyr, gen(gaga2)
sum gaga2, det
sum betnr_n if gaga2>0
drop if gaga2>0

// now each duplicate takes a separate firm name
drop betnr
rename betnr_n betnr

*********
** GMM Estimation
*********
count

sort betnr calyr

// reshape for gmmcovearn to run

quietly{
keep betnr calyr del2_ue
reshape wide del2_ue, i(betnr) j(calyr)
set matsize 2000 // change back to 2000
local fy=2011-`ny'
forval i=`fy'/2010{
local jj=`i'-2010+`ny'
rename del2_ue`i' del2_ue`jj'
}
}
count

compress
clear matrix

count

noi gmmcovearn del2_ue, yearn(`ny') modeln(1) newdataname(hoy) stvalue(.000064, .05, .0024, .0013, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2)

// construct standard deviation of permanent component (command saves the variance)
mat param=e(b)
mat pp=param[1,1]

mat perm2=J(1,`ny',0)

mat p=1
mat perm2[1,1]=sqrt(p[1,1]^2*pp[1,1]) // first period

forval gg=2/`ny'{
mat p=param[1,`ny'+2+`gg']
mat perm2[1,`gg']=sqrt(p[1,1]^2*pp[1,1]) // this is just the standard deviation of the permanent component for different years (year specific loadings)
}

noi mat list perm2 , format(%8.5f) 


if `simul'==1 {
mat2txt, matrix(perm2) saving(log/perm) replace
}



*************************************************************************************************************************
*********** 2) now with additional age controls otherwise exactly the same 
*************************************************************************************************************************

use "$data/firm_delta.dta", replace

if `simul'==1{
gen firmage=floor(runiform()*100) // just make up a random firmage between 0 and 100 for simulated data
}

if `simul'==0{ 
gen firmage=calyr-grd_jahr if grd_jahr>1975
replace firmage=calyr-(1900+floor(runiform()*76)) if grd_jahr==1975
}

drop if firmage<0
drop if firmage==.
local ny=36

keep del2_ue betemp grd_jahr calyr betnr firmage

// clean up
count if betnr==.
count
drop if betnr==.
drop if betnr==.n
drop if betnr==.z

// just replace the strings with id=1,2,...N
egen bet2=group(betnr)
replace betnr=bet2

// the next block duplicates firms based on size (as a means of weighting). first step, express employment relative to smallest employer (does nothing in the data)
sum betemp, det
local minsz=r(min)
replace betemp=betemp/`minsz'

// duplicates observations according to betemp. this does the weighting
expand betemp 

// next block treats the duplicates as separate firms with different firm-id
bys betnr calyr: gen long grr=_n
egen long tgt=tag(betnr grr)
sort betnr grr calyr
gen long betnr_n=sum(tgt)

// drops duplicate firm-year observations
duplicates tag betnr_n calyr, gen(gaga2)
sum gaga2, det
sum betnr_n if gaga2>0
drop if gaga2>0

// now each duplicate takes a separate firm name
drop betnr
rename betnr_n betnr

*********
** GMM Estimation
*********
sort betnr calyr

quietly{
keep betnr calyr del2_ue firmage
reshape wide del2_ue firmage, i(betnr) j(calyr)
set matsize 2000
local fy=2011-`ny'
forval i=`fy'/2010{
local jj=`i'-2010+`ny'
rename del2_ue`i' del2_ue`jj'
rename firmage`i' firmage`jj'
}
}

forval hh=1/`ny'{
gen fa`hh'_2=firmage`hh'^2 
}

compress
clear matrix

noi gmmcovearn del2_ue, yearn(`ny') modeln(3) expvar(firmage) stvalue(.000064, .05, .0024, .0013, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 5e-08, -2e-06)

// construct standard deviation of permanent component (command saves the variance)
mat param=e(b)
mat sigb=param[1,`ny'*2+3]
mat covab=param[1,`ny'*2+4]
mat siga=param[1,1]

noi sum firmage1
local agemean=r(mean)
noi sum fa1_2
local age2mean=r(mean)

mat perm2=J(1,`ny',0)
mat p=1
mat perm2[1,1]=sqrt(p[1,1]^2*(siga[1,1]+covab[1,1]*`agemean'+sigb[1,1]*`age2mean')) // this is just the standard deviation of the permanent component
forval gg=2/`ny'{
qui sum firmage`ny'
local agemean=r(mean) 
qui sum fa`gg'_2 
local age2mean=r(mean)
mat p=param[1,`ny'+2+`gg']
mat perm2[1,`gg']=sqrt(p[1,1]^2*(siga[1,1]+covab[1,1]*`agemean'+sigb[1,1]*`age2mean')) // this is just the standard deviation of the permanent component
}
noi mat list perm2 , format(%8.5f) 

if `simul'==1 {
mat2txt, matrix(perm2) saving(log/perm2) replace
}


*************************************************************************************************************************
*********** 3) FIRMAGE IS CENSORED SO NOW WE DO IT ONLY WITH FIRMS THAT ARE "BORN" PAST 1975
*************************************************************************************************************************

use "$data/firm_delta.dta", replace

if `simul'==1{
gen firmage=floor(runiform()*100) // just make up a random firmage between 0 and 100 for simulated data
}
if `simul'==0{ 
gen firmage=calyr-grd_jahr
}

drop if firmage<0
drop if firmage==.
drop if grd_jahr==1975

local ny=35

keep del2_ue betemp grd_jahr calyr betnr firmage

// clean up
count if betnr==.
count
drop if betnr==.
drop if betnr==.n
drop if betnr==.z

// just replace the strings with id=1,2,...N
egen bet2=group(betnr)
replace betnr=bet2

// the next block duplicates firms based on size (as a means of weighting). first step, express employment relative to smallest employer (does nothing in the data)
sum betemp, det
local minsz=r(min)
replace betemp=betemp/`minsz'

// duplicates observations according to betemp. this does the weighting
expand betemp 

// next block treats the duplicates as separate firms with different firm-id
bys betnr calyr: gen long grr=_n
egen long tgt=tag(betnr grr)
sort betnr grr calyr
gen long betnr_n=sum(tgt)

// drops duplicate firm-year observations
duplicates tag betnr_n calyr, gen(gaga2)
sum gaga2, det
sum betnr_n if gaga2>0
drop if gaga2>0

// now each duplicate takes a separate firm name
drop betnr
rename betnr_n betnr

*********
** GMM Estimation
*********
sort betnr calyr

quietly{
keep betnr calyr del2_ue firmage
reshape wide del2_ue firmage, i(betnr) j(calyr)
set matsize 2000
local fy=2011-`ny'
forval i=`fy'/2010{
local jj=`i'-2010+`ny'
rename del2_ue`i' del2_ue`jj'
rename firmage`i' firmage`jj'
}
}

forval hh=1/`ny'{
gen fa`hh'_2=firmage`hh'^2 
}

compress
clear matrix

noi gmmcovearn del2_ue, yearn(`ny') modeln(3) expvar(firmage) stvalue(.000064, .05, .0024, .0013, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 5e-08, -2e-06)

// construct standard deviation of permanent component (command saves the variance)
mat param=e(b)
mat sigb=param[1,`ny'*2+3]
mat covab=param[1,`ny'*2+4]
mat siga=param[1,1]

noi sum firmage1
local agemean=r(mean)
noi sum fa1_2
local age2mean=r(mean)

mat perm2=J(1,`ny',0)
mat p=1
mat perm2[1,1]=sqrt(p[1,1]^2*(siga[1,1]+covab[1,1]*`agemean'+sigb[1,1]*`age2mean')) // this is just the standard deviation of the permanent component
forval gg=2/`ny'{
qui sum firmage`ny'
local agemean=r(mean) 
qui sum fa`gg'_2 
local age2mean=r(mean)
mat p=param[1,`ny'+2+`gg']
mat perm2[1,`gg']=sqrt(p[1,1]^2*(siga[1,1]+covab[1,1]*`agemean'+sigb[1,1]*`age2mean')) // this is just the standard deviation of the permanent component
}
noi mat list perm2 , format(%8.5f) 

if `simul'==1 {
mat2txt, matrix(perm2) saving(log/perm3) replace
}


}


