// This runs displacement regressions (in addition to file regression_520). Instead of showing all the regression tables I print the relevant coefficients into a matrix along with the number of observations used
// This file specifically runs some robustness regressions and quantile regressions
// The comment below in line 15 is important. need to run this after running file 6_regression_520 for case 1.

clear

cap log close
set more off
set seed 123456789

local simul=1 // set this to 1 to run the code on simulated model based data

log using "$log/6_regression_xtnd.log", replace

use "$data/regression_sample_full", clear //this file is separately constructed in the file regression_520. make sure that the current file is for model 1 before running this

set matsize 10000

//quietly{
*******************************************************
************ LOG EARNINGS RESPONSE TO JOB LOSS
**********************************************************
if `simul'==0{
*standard fixed effect displacement regression
qui reghdfe lave Dl*, a(persnr age calyr) vce(cluster persorig yearorig)
mat coef=e(b)
mat c_le_fe=coef[1,1..26]
mat c_le_fe_n=e(N)
mat var=e(V)
mat var2=vecdiag(var)
mat c_le_fe_v=var2[1,1..26] 

qui reghdfe lavw Dl*, a(persnr age calyr) vce(cluster persorig yearorig)
mat coef=e(b)
mat c_lw_fe=coef[1,1..26]
mat c_lw_fe_n=e(N)
mat var=e(V)
mat var2=vecdiag(var)
mat c_lw_fe_v=var2[1,1..26]

* linear controls
qui reghdfe lave Dl* ebar2 ebar4, a(calyr age) vce(cluster persorig yearorig)
mat coef=e(b)
mat c_le_fee1=coef[1,1..26]
mat c_le_fee1_n=e(N)
mat var=e(V)
mat var2=vecdiag(var)
mat c_le_fee1_v=var2[1,1..26] 

* print results
mat results_ext1=[ c_le_fe \ c_le_fe_v \ c_lw_fe \ c_lw_fe_v \ c_le_fee1 \ c_le_fee1_v]'
mat colnames results_ext1= FE_E FE_E_V FE_W FE_W_V FEE1 FEE1_V
noi mat list results_ext1, format(%8.5f)

// this stores the results for the model in a txt file that can be read into matlab
if `simul'==1{
mat2txt, matrix(results_ext1) saving(log/losses_ext1) replace
}
//}

mat n=[ c_le_fe_n[1,1] \ c_lw_fe_n \ c_le_fee1_n[1,1]]'
mat colnames n= N_LE_FE N_Lw_FE N_LE_FEE1
noi display "This shows the number of observations used in the regresssions behind the previous matrix"
noi mat list n
}

//this is to shrink the filesize, I keep only a small but sufficient fraction of the control group for the quantile regressions
bys persnr: gen sample=runiform() if _n==1
bys persnr: egen sample2=max(sample)
count
drop if sample2>.01 & lossiny==0
count
drop sample sample2

qui xi: laplacereg lave Dl* i.frste i.lste i.age i.calyr, q(.1 .25 .5 .75 .9 ) tolerance(1e-5) maxiter(1000)
mat coef=e(b)

local dim `=colsof(coef)'
local dim2=`dim'/5

forval u=0/4{
local g1=1+`u'*`dim2'
local g2=26+`u'*`dim2'
mat c_le_q`u'=coef[1,`g1'..`g2']
}

mat c_le_q10= c_le_q0
mat c_le_q25= c_le_q1
mat c_le_q50= c_le_q2
mat c_le_q75= c_le_q3
mat c_le_q90= c_le_q4

mat c_le_q10_n=e(N)
mat c_le_q25_n=e(N)
mat c_le_q50_n=e(N)
mat c_le_q75_n=e(N)
mat c_le_q90_n=e(N)

mat results_ext=[ c_le_fe \ c_le_fee1 \  c_le_q10 \ c_le_q25  \ c_le_q50  \ c_le_q75 \ c_le_q90 ]'
mat colnames results_ext= LE_FE LE_FEE1 LE_Q10 LE_Q25 LE_Q50 LE_Q75 LE_Q90
mat rext=results_ext'
noi mat list rext, format(%8.5f)
mat n_ext=[ c_le_fe_n \ c_le_fee1_n \  c_le_q10_n \ c_le_q25_n \ c_le_q50_n \ c_le_q75_n \ c_le_q90_n ]'
mat colnames n_ext= N_LE_FE N_LE_FEE1  N_LE_Q10 N_LE_Q25 N_LE_Q50 N_LE_Q75 N_LE_Q90

noi display "This shows the number of observations used in the regresssions behind the previous matrix"
noi mat list n_ext

// this stores the results for the model in a txt file that can be read into matlab
if `simul'==1{
mat2txt, matrix(results_ext) saving(log/losses_ext) replace
}

//}
