clear

set more off

local mod=3 // set to 2 and 3 for the two no heterogeneity datasets

if `mod'==1{
import delimited "$simul/data_fake.csv", clear
}
if `mod'==2{
import delimited "$simul/data_fake_het_delta.csv", clear
}
if `mod'==3{
import delimited "$simul/data_fake_het_s.csv", clear
}


rename v1 persnr
rename v2 date
sum v4 if v3==0
rename v4 wage
rename v5 firm

rename v6 eten
rename v7 jten
rename v8 udur

bys persnr: gen smple=runiform() if _n==1
bys persnr: egen sample2=max(smple)
drop  if sample2>1
drop smple sample2

gen frau=uniform()<.5
gen bild=uniform()<.5
gen beruf=uniform()<.5
gen betnr=firm


*** Generate the jobloss variable
bys persnr (date), sort: gen jobloss=wage[_n+1]==0&wage[_n]>0&_n>1
gen jobloss_ue=jobloss
** generate emp variable 0 if unemployed, 1 if employed 
gen emp=0
replace emp=1 if wage>0

gen jobtojob=(emp[_n]==1 & emp[_n+1]==1 & firm[_n]!=firm[_n+1] & persnr[_n]==persnr[_n+1])

*** Generate variable for years
gen calyr = ceil(date/12)
gen calmn = date-(calyr-1)*12
gen caldate=ym(calyr,calmn)
format caldate %tm

gen age = 25+30*runiform()
replace age=ceil(age)

replace calyr=calyr+1974

*** Turn wage into earnings and create a wage variable
bys persnr calyr: egen avw=mean(wage) if(emp==1)

* earnings during months of full time employment
bys persnr calyr: egen ave=sum(wage) if(emp==1)
replace ave=ave/12

*** jobloss for sample selection criteria 
gen jobloss_ten2=0
bys persnr: replace jobloss_ten2 =1 if (jobloss[_n]==1 & jten[_n-1]>=36) 
bys persnr: replace jobloss_ten2 =0 if (jobloss[_n]==0 & jten[_n-1]>=36)

save "$simul/monthly_simul.dta", replace

*** Create a variable for latest firm in the year
gen emp_sum=emp

*** Collapse to year-based panel
collapse  (max) jobloss* av* (first) betnr age jten frau bild beruf, by(persnr calyr)

/*
* generate the separation risk variable
gen sep_risk = . 
replace sep_risk=jobloss_sum/emp_sum if emp_sum >0
gen sep_risk_ue=sep_risk
*/

*** Create age variable
compress

drop if calyr>2010
gen jobloss_ten_ue=jobloss_ten

* generate a variable which indicates whether person lost job in a given year
rename jobloss_ten_ue jobloss_4
rename jobloss_ten jobloss_3
rename jobloss_ue jobloss_2
rename jobloss jobloss_1

gen jobloss_5 =jobloss_4
gen jobloss_7 =jobloss_4
gen jobloss_9 =jobloss_4

gen avw_b=avw
gen ave_b=ave


if `mod'==2{

set seed 123456789

bys persnr: gen sample=runiform() if _n==1
bys persnr: egen sample2=max(sample)
count
keep if sample2<.4
count
drop sample sample2

save "$simul/annual_simul_het_delta.dta", replace
}
if `mod'==3{

set seed 123456789

bys persnr: gen sample=runiform() if _n==1
bys persnr: egen sample2=max(sample)
count
keep if sample2<.4
count
drop sample sample2

save "$simul/annual_simul_het_s.dta", replace
}

if `mod'==1{
save "$simul/annual_simul.dta", replace

set seed 123456789

bys persnr: gen sample=runiform() if _n==1
bys persnr: egen sample2=max(sample)
count
keep if sample2<.25
count
preserve
drop sample sample2
save "$simul/annual_simul_small.dta", replace
restore
count
keep if sample2<.05
count
preserve
drop sample sample2
save "$simul/annual_simul_vsmall.dta", replace
}
